# coding: utf-8
# This file is auto-generated from samples_lanauge_*. For copying, see
# notices there.

from typeatlas.samples import add_sample
from typeatlas.samples import PRIO_PREFER, PRIO_WITHHOLD, PRIO_DEFAULT


add_sample('en-gb', '⠠⠮ ⠟⠅ ⠃⠗⠪⠝ ⠋⠕⠭ ⠚⠥⠍⠏⠎ ⠕⠧⠻ ⠮ ⠎⠇⠂⠵⠽ ⠊⠖⠽ ⠙⠕⠛⠲',
           original='The quick brown fox jumps over the sleazy iffy dog.',
           english='The quick brown fox jumps over the sleazy iffy dog.',
           script='Brai', flags=['grade2'], prio=PRIO_PREFER,
           sources=[])


add_sample('en-in', '⠠⠞⠓⠑ ⠟⠥⠊⠉⠅ ⠃⠗⠕⠺⠝ ⠋⠕⠭ ⠚⠥⠍⠏⠎ ⠕⠧⠑⠗ ⠞⠓⠑ ⠎⠇⠑⠁⠵⠽ ⠊⠋⠋⠽ ⠙⠕⠛⠲',
           original='The quick brown fox jumps over the sleazy iffy dog.',
           english='The quick brown fox jumps over the sleazy iffy dog.',
           script='Brai', flags=['grade1'], prio=PRIO_WITHHOLD,
           sources=[])


add_sample('en-us', '⠠⠞⠓⠑ ⠟⠥⠊⠉⠅ ⠃⠗⠕⠺⠝ ⠋⠕⠭ ⠚⠥⠍⠏⠎ ⠕⠧⠑⠗ ⠞⠓⠑ ⠎⠇⠑⠁⠵⠽ ⠊⠋⠋⠽ ⠙⠕⠛⠲',
           original='The quick brown fox jumps over the sleazy iffy dog.',
           english='The quick brown fox jumps over the sleazy iffy dog.',
           script='Brai', flags=['grade1'], prio=PRIO_WITHHOLD,
           sources=[])


add_sample('en-us', '⠠⠮ ⠟⠅ ⠃⠗⠪⠝ ⠋⠕⠭ ⠚⠥⠍⠏⠎ ⠕⠧⠻ ⠮ ⠎⠇⠂⠵⠽ ⠊⠖⠽ ⠙⠕⠛⠲',
           original='The quick brown fox jumps over the sleazy iffy dog.',
           english='The quick brown fox jumps over the sleazy iffy dog.',
           script='Brai', flags=['grade2'], prio=PRIO_PREFER,
           sources=[])


add_sample('en-gb', '⠠⠚⠁⠉⠅⠙⠁⠺⠎ ⠇⠕⠧⠑ ⠍⠽ ⠃⠊⠛ ⠎⠏⠓⠔⠭ ⠷ ⠟⠥⠜⠞⠵⠲',
           original='Jackdaws love my big sphinx of quartz.',
           english='Jackdaws love my big sphinx of quartz.',
           script='Brai', flags=['grade2'], prio=PRIO_PREFER,
           sources=['List of Pangrams, Wikipedia, 12 October 2014 <https://web.archive.org/web/20141012231620/http://en.wikipedia.org/wiki/List_of_pangrams>'])


add_sample('en-in', '⠠⠚⠁⠉⠅⠙⠁⠺⠎ ⠇⠕⠧⠑ ⠍⠽ ⠃⠊⠛ ⠎⠏⠓⠊⠝⠭ ⠕⠋ ⠟⠥⠁⠗⠞⠵⠲',
           original='Jackdaws love my big sphinx of quartz.',
           english='Jackdaws love my big sphinx of quartz.',
           script='Brai', flags=['grade1'], prio=PRIO_WITHHOLD,
           sources=['List of Pangrams, Wikipedia, 12 October 2014 <https://web.archive.org/web/20141012231620/http://en.wikipedia.org/wiki/List_of_pangrams>'])


add_sample('en-us', '⠠⠚⠁⠉⠅⠙⠁⠺⠎ ⠇⠕⠧⠑ ⠍⠽ ⠃⠊⠛ ⠎⠏⠓⠊⠝⠭ ⠕⠋ ⠟⠥⠁⠗⠞⠵⠲',
           original='Jackdaws love my big sphinx of quartz.',
           english='Jackdaws love my big sphinx of quartz.',
           script='Brai', flags=['grade1'], prio=PRIO_WITHHOLD,
           sources=['List of Pangrams, Wikipedia, 12 October 2014 <https://web.archive.org/web/20141012231620/http://en.wikipedia.org/wiki/List_of_pangrams>'])


add_sample('en-us', '⠠⠚⠁⠉⠅⠙⠁⠺⠎ ⠇⠕⠧⠑ ⠍⠽ ⠃⠊⠛ ⠎⠏⠓⠔⠭ ⠷ ⠟⠥⠜⠞⠵⠲',
           original='Jackdaws love my big sphinx of quartz.',
           english='Jackdaws love my big sphinx of quartz.',
           script='Brai', flags=['grade2'], prio=PRIO_PREFER,
           sources=['List of Pangrams, Wikipedia, 12 October 2014 <https://web.archive.org/web/20141012231620/http://en.wikipedia.org/wiki/List_of_pangrams>'])


add_sample('en-gb', '⠠⠓⠪ ⠧⠑⠭⠬⠇⠽ ⠟⠅ ⠙⠁⠋⠞ ⠵⠑⠃⠗⠁⠎ ⠚⠥⠍⠏⠖',
           original='How vexingly quick daft zebras jump!',
           english='How vexingly quick daft zebras jump!',
           script='Brai', flags=['grade2'], prio=PRIO_PREFER,
           sources=['Pangram - Wikipedia, 23:33, 15 May 2018 <https://en.wikipedia.org/w/index.php?title=Pangram&oldid=841455362>'])


add_sample('en-in', '⠠⠓⠕⠺ ⠧⠑⠭⠊⠝⠛⠇⠽ ⠟⠥⠊⠉⠅ ⠙⠁⠋⠞ ⠵⠑⠃⠗⠁⠎ ⠚⠥⠍⠏⠖',
           original='How vexingly quick daft zebras jump!',
           english='How vexingly quick daft zebras jump!',
           script='Brai', flags=['grade1'], prio=PRIO_WITHHOLD,
           sources=['Pangram - Wikipedia, 23:33, 15 May 2018 <https://en.wikipedia.org/w/index.php?title=Pangram&oldid=841455362>'])


add_sample('en-us', '⠠⠓⠕⠺ ⠧⠑⠭⠊⠝⠛⠇⠽ ⠟⠥⠊⠉⠅ ⠙⠁⠋⠞ ⠵⠑⠃⠗⠁⠎ ⠚⠥⠍⠏⠖',
           original='How vexingly quick daft zebras jump!',
           english='How vexingly quick daft zebras jump!',
           script='Brai', flags=['grade1'], prio=PRIO_WITHHOLD,
           sources=['Pangram - Wikipedia, 23:33, 15 May 2018 <https://en.wikipedia.org/w/index.php?title=Pangram&oldid=841455362>'])


add_sample('en-us', '⠠⠓⠪ ⠧⠑⠭⠬⠇⠽ ⠟⠅ ⠙⠁⠋⠞ ⠵⠑⠃⠗⠁⠎ ⠚⠥⠍⠏⠖',
           original='How vexingly quick daft zebras jump!',
           english='How vexingly quick daft zebras jump!',
           script='Brai', flags=['grade2'], prio=PRIO_PREFER,
           sources=['Pangram - Wikipedia, 23:33, 15 May 2018 <https://en.wikipedia.org/w/index.php?title=Pangram&oldid=841455362>'])


add_sample('en-gb', '⠠⠹ ⠏⠁⠝⠛⠗⠁⠍ ⠒⠞⠁⠔⠎ ⠋⠳⠗ ⠠⠵⠂ ⠐⠕ ⠰⠠⠃⠂ ⠞⠺⠕ ⠠⠉⠎⠂ ⠐⠕ ⠰⠠⠙⠂ ⠹⠊⠗⠞⠽ ⠠⠑⠎⠂ ⠎⠊⠭ ⠠⠋⠎⠂ ⠋⠊⠧⠑ ⠠⠛⠎⠂ ⠎⠑⠧⠢ ⠠⠓⠎⠂ ⠑⠇⠑⠧⠢ ⠠⠊⠎⠂ ⠐⠕ ⠰⠠⠚⠂ ⠐⠕ ⠰⠠⠅⠂ ⠞⠺⠕ ⠠⠇⠎⠂ ⠞⠺⠕ ⠠⠍⠎⠂ ⠑⠊⠣⠞⠑⠢ ⠠⠝⠎⠂ ⠋⠊⠋⠞⠑⠢ ⠠⠕⠎⠂ ⠞⠺⠕ ⠠⠏⠎⠂ ⠐⠕ ⠰⠠⠟⠂ ⠋⠊⠧⠑ ⠠⠗⠎⠂ ⠞⠺⠢⠞⠽⠤⠎⠑⠧⠢ ⠠⠎⠎⠂ ⠑⠊⠣⠞⠑⠢ ⠠⠞⠎⠂ ⠞⠺⠕ ⠠⠥⠂ ⠎⠑⠧⠢ ⠠⠧⠎⠂ ⠑⠊⠣⠞ ⠠⠺⠎⠂ ⠞⠺⠕ ⠰⠠⠭⠎⠂ ⠹⠗⠑⠑ ⠠⠽⠎⠂ ⠈⠯ ⠐⠕ ⠰⠠⠵⠲',
           original='This pangram contains four As, one B, two Cs, one D, thirty Es, six Fs, five Gs, seven Hs, eleven Is, one J, one K, two Ls, two Ms, eighteen Ns, fifteen Os, two Ps, one Q, five Rs, twenty-seven Ss, eighteen Ts, two Us, seven Vs, eight Ws, two Xs, three Ys, & one Z.',
           english='This pangram contains four As, one B, two Cs, one D, thirty Es, six Fs, five Gs, seven Hs, eleven Is, one J, one K, two Ls, two Ms, eighteen Ns, fifteen Os, two Ps, one Q, five Rs, twenty-seven Ss, eighteen Ts, two Us, seven Vs, eight Ws, two Xs, three Ys, & one Z.',
           script='Brai', flags=['grade2'], prio=PRIO_PREFER,
           sources=['Pangram - Wikipedia, 23:33, 15 May 2018 <https://en.wikipedia.org/w/index.php?title=Pangram&oldid=841455362>'])


add_sample('en-in', '⠠⠞⠓⠊⠎ ⠏⠁⠝⠛⠗⠁⠍ ⠉⠕⠝⠞⠁⠊⠝⠎ ⠋⠕⠥⠗ ⠠⠁⠎⠂ ⠕⠝⠑ ⠠⠃⠂ ⠞⠺⠕ ⠠⠉⠎⠂ ⠕⠝⠑ ⠠⠙⠂ ⠞⠓⠊⠗⠞⠽ ⠠⠑⠎⠂ ⠎⠊⠭ ⠠⠋⠎⠂ ⠋⠊⠧⠑ ⠠⠛⠎⠂ ⠎⠑⠧⠑⠝ ⠠⠓⠎⠂ ⠑⠇⠑⠧⠑⠝ ⠠⠊⠎⠂ ⠕⠝⠑ ⠠⠚⠂ ⠕⠝⠑ ⠠⠅⠂ ⠞⠺⠕ ⠠⠇⠎⠂ ⠞⠺⠕ ⠠⠍⠎⠂ ⠑⠊⠛⠓⠞⠑⠑⠝ ⠠⠝⠎⠂ ⠋⠊⠋⠞⠑⠑⠝ ⠠⠕⠎⠂ ⠞⠺⠕ ⠠⠏⠎⠂ ⠕⠝⠑ ⠠⠟⠂ ⠋⠊⠧⠑ ⠠⠗⠎⠂ ⠞⠺⠑⠝⠞⠽⠤⠎⠑⠧⠑⠝ ⠠⠎⠎⠂ ⠑⠊⠛⠓⠞⠑⠑⠝ ⠠⠞⠎⠂ ⠞⠺⠕ ⠠⠥⠎⠂ ⠎⠑⠧⠑⠝ ⠠⠧⠎⠂ ⠑⠊⠛⠓⠞ ⠠⠺⠎⠂ ⠞⠺⠕ ⠠⠭⠎⠂ ⠞⠓⠗⠑⠑ ⠠⠽⠎⠂ ⠈⠯ ⠕⠝⠑ ⠠⠵⠲',
           original='This pangram contains four As, one B, two Cs, one D, thirty Es, six Fs, five Gs, seven Hs, eleven Is, one J, one K, two Ls, two Ms, eighteen Ns, fifteen Os, two Ps, one Q, five Rs, twenty-seven Ss, eighteen Ts, two Us, seven Vs, eight Ws, two Xs, three Ys, & one Z.',
           english='This pangram contains four As, one B, two Cs, one D, thirty Es, six Fs, five Gs, seven Hs, eleven Is, one J, one K, two Ls, two Ms, eighteen Ns, fifteen Os, two Ps, one Q, five Rs, twenty-seven Ss, eighteen Ts, two Us, seven Vs, eight Ws, two Xs, three Ys, & one Z.',
           script='Brai', flags=['grade1'], prio=PRIO_WITHHOLD,
           sources=['Pangram - Wikipedia, 23:33, 15 May 2018 <https://en.wikipedia.org/w/index.php?title=Pangram&oldid=841455362>'])


add_sample('en-us', '⠠⠞⠓⠊⠎ ⠏⠁⠝⠛⠗⠁⠍ ⠉⠕⠝⠞⠁⠊⠝⠎ ⠋⠕⠥⠗ ⠠⠁⠎⠂ ⠕⠝⠑ ⠰⠠⠃⠂ ⠞⠺⠕ ⠠⠉⠎⠂ ⠕⠝⠑ ⠰⠠⠙⠂ ⠞⠓⠊⠗⠞⠽ ⠠⠑⠎⠂ ⠎⠊⠭ ⠠⠋⠎⠂ ⠋⠊⠧⠑ ⠠⠛⠎⠂ ⠎⠑⠧⠑⠝ ⠠⠓⠎⠂ ⠑⠇⠑⠧⠑⠝ ⠠⠊⠎⠂ ⠕⠝⠑ ⠰⠠⠚⠂ ⠕⠝⠑ ⠰⠠⠅⠂ ⠞⠺⠕ ⠠⠇⠎⠂ ⠞⠺⠕ ⠠⠍⠎⠂ ⠑⠊⠛⠓⠞⠑⠑⠝ ⠠⠝⠎⠂ ⠋⠊⠋⠞⠑⠑⠝ ⠠⠕⠎⠂ ⠞⠺⠕ ⠠⠏⠎⠂ ⠕⠝⠑ ⠰⠠⠟⠂ ⠋⠊⠧⠑ ⠠⠗⠎⠂ ⠞⠺⠑⠝⠞⠽⠤⠎⠑⠧⠑⠝ ⠠⠎⠎⠂ ⠑⠊⠛⠓⠞⠑⠑⠝ ⠠⠞⠎⠂ ⠞⠺⠕ ⠠⠥⠎⠂ ⠎⠑⠧⠑⠝ ⠠⠧⠎⠂ ⠑⠊⠛⠓⠞ ⠠⠺⠎⠂ ⠞⠺⠕ ⠠⠭⠎⠂ ⠞⠓⠗⠑⠑ ⠠⠽⠎⠂ ⠈⠯ ⠕⠝⠑ ⠠⠵⠲',
           original='This pangram contains four As, one B, two Cs, one D, thirty Es, six Fs, five Gs, seven Hs, eleven Is, one J, one K, two Ls, two Ms, eighteen Ns, fifteen Os, two Ps, one Q, five Rs, twenty-seven Ss, eighteen Ts, two Us, seven Vs, eight Ws, two Xs, three Ys, & one Z.',
           english='This pangram contains four As, one B, two Cs, one D, thirty Es, six Fs, five Gs, seven Hs, eleven Is, one J, one K, two Ls, two Ms, eighteen Ns, fifteen Os, two Ps, one Q, five Rs, twenty-seven Ss, eighteen Ts, two Us, seven Vs, eight Ws, two Xs, three Ys, & one Z.',
           script='Brai', flags=['grade1'], prio=PRIO_WITHHOLD,
           sources=['Pangram - Wikipedia, 23:33, 15 May 2018 <https://en.wikipedia.org/w/index.php?title=Pangram&oldid=841455362>'])


add_sample('en-us', '⠠⠹ ⠏⠁⠝⠛⠗⠁⠍ ⠒⠞⠁⠔⠎ ⠋⠳⠗ ⠠⠵⠂ ⠐⠕ ⠰⠠⠃⠂ ⠞⠺⠕ ⠠⠉⠎⠂ ⠐⠕ ⠰⠠⠙⠂ ⠹⠊⠗⠞⠽ ⠠⠑⠎⠂ ⠎⠊⠭ ⠠⠋⠎⠂ ⠋⠊⠧⠑ ⠠⠛⠎⠂ ⠎⠑⠧⠢ ⠠⠓⠎⠂ ⠑⠇⠑⠧⠢ ⠠⠊⠎⠂ ⠐⠕ ⠰⠠⠚⠂ ⠐⠕ ⠰⠠⠅⠂ ⠞⠺⠕ ⠠⠇⠎⠂ ⠞⠺⠕ ⠠⠍⠎⠂ ⠑⠊⠣⠞⠑⠢ ⠠⠝⠎⠂ ⠋⠊⠋⠞⠑⠢ ⠠⠕⠎⠂ ⠞⠺⠕ ⠠⠏⠎⠂ ⠐⠕ ⠰⠠⠟⠂ ⠋⠊⠧⠑ ⠠⠗⠎⠂ ⠞⠺⠢⠞⠽⠤⠎⠑⠧⠢ ⠠⠎⠎⠂ ⠑⠊⠣⠞⠑⠢ ⠠⠞⠎⠂ ⠞⠺⠕ ⠠⠥⠂ ⠎⠑⠧⠢ ⠠⠧⠎⠂ ⠑⠊⠣⠞ ⠠⠺⠎⠂ ⠞⠺⠕ ⠰⠠⠭⠎⠂ ⠹⠗⠑⠑ ⠠⠽⠎⠂ ⠈⠯ ⠐⠕ ⠠⠵⠲',
           original='This pangram contains four As, one B, two Cs, one D, thirty Es, six Fs, five Gs, seven Hs, eleven Is, one J, one K, two Ls, two Ms, eighteen Ns, fifteen Os, two Ps, one Q, five Rs, twenty-seven Ss, eighteen Ts, two Us, seven Vs, eight Ws, two Xs, three Ys, & one Z.',
           english='This pangram contains four As, one B, two Cs, one D, thirty Es, six Fs, five Gs, seven Hs, eleven Is, one J, one K, two Ls, two Ms, eighteen Ns, fifteen Os, two Ps, one Q, five Rs, twenty-seven Ss, eighteen Ts, two Us, seven Vs, eight Ws, two Xs, three Ys, & one Z.',
           script='Brai', flags=['grade2'], prio=PRIO_PREFER,
           sources=['Pangram - Wikipedia, 23:33, 15 May 2018 <https://en.wikipedia.org/w/index.php?title=Pangram&oldid=841455362>'])


add_sample('bg', '⡵⠁ ⠍⠊⠛ ⠃⠫⠓ ⠺ ⠟⠥⠚⠙⠂ ⠎⠅⠷⠗⠉⠁⠭ ⠏⠇⠳⠱⠑⠝ ⠋⠕⠞⠾⠕⠽⠇⠲',
           original='За миг бях в чужд, скърцащ плюшен фотьойл.',
           english="For a moment I was in another's, creaking plush armchair.",
           script='Brai', flags=[], prio=PRIO_DEFAULT,
           sources=['List of Pangrams, Wikipedia, 12 October 2014 <https://web.archive.org/web/20141012231620/http://en.wikipedia.org/wiki/List_of_pangrams>'])


add_sample('bg', '⡏⠕⠙ ⠳⠚⠝⠕ ⠙⠷⠗⠺⠕⠂ ⠉⠷⠋⠞⠫⠭⠕ ⠺ ⠎⠊⠝⠾⠕⠂ ⠃⠫⠛⠁⠱⠑ ⠍⠁⠇⠅⠕ ⠏⠥⠓⠅⠁⠺⠕ ⠵⠁⠽⠟⠑⠲',
           original='Под южно дърво, цъфтящо в синьо, бягаше малко пухкаво зайче.',
           english='Under a southern tree, blooming in blue, a little fluffy rabbit was running.',
           script='Brai', flags=[], prio=PRIO_DEFAULT,
           sources=['List of Pangrams, Wikipedia, 12 October 2014 <https://web.archive.org/web/20141012231620/http://en.wikipedia.org/wiki/List_of_pangrams>', 'Pango Language Sample Table'])


add_sample('bg', '⡚⠷⠇⠞⠁⠞⠁ ⠙⠳⠇⠫ ⠃⠑⠱⠑ ⠭⠁⠎⠞⠇⠊⠺⠁⠂ ⠟⠑ ⠏⠥⠓⠷⠞⠂ ⠅⠕⠽⠞⠕ ⠉⠷⠋⠝⠁⠂ ⠵⠁⠍⠗⠷⠵⠝⠁ ⠅⠁⠞⠕ ⠛⠾⠕⠝⠲',
           original='Жълтата дюля беше щастлива, че пухът, който цъфна, замръзна като гьон.',
           english='The yellow quince was happy that the fluff which bloomed froze like sole-leather.',
           script='Brai', flags=[], prio=PRIO_DEFAULT,
           sources=['List of Pangrams, Wikipedia, 12 October 2014 <https://web.archive.org/web/20141012231620/http://en.wikipedia.org/wiki/List_of_pangrams>'])


add_sample('de', '⠵⠺⠪⠇⠋ ⠃⠕⠭⠅⠜⠍⠏⠋⠑⠗ ⠚⠁⠛⠑⠝ ⠧⠊⠅⠞⠕⠗ ⠟⠥⠑⠗ ⠳⠃⠑⠗ ⠙⠑⠝ ⠛⠗⠕⠮⠑⠝ ⠎⠽⠇⠞⠑⠗ ⠙⠩⠹⠄',
           original='Zwölf Boxkämpfer jagen Viktor quer über den großen Sylter Deich.',
           english='Twelve boxers chase Viktor over the great dam of Sylt.',
           script='Brai', flags=['grade1'], prio=PRIO_WITHHOLD,
           sources=['Pangramm - Wikipedia, 2. November 2017 um 16:04 <https://de.wikipedia.org/w/index.php?title=Pangramm&oldid=170578983>', 'Pango Language Sample Table'])


add_sample('de', '⠵⠺⠪⠇⠋ ⠃⠕⠠⠭⠅⠜⠍⠏⠋⠻ ⠚⠁⠛⠉ ⠧⠊⠅⠞⠕⠗ ⠠⠟⠥⠻ ⠳ ⠑ ⠛⠮⠉ ⠎⠠⠽⠇⠞⠻ ⠙⠩⠹⠄',
           original='Zwölf Boxkämpfer jagen Viktor quer über den großen Sylter Deich.',
           english='Twelve boxers chase Viktor over the great dam of Sylt.',
           script='Brai', flags=['grade2'], prio=PRIO_PREFER,
           sources=['Pangramm - Wikipedia, 2. November 2017 um 16:04 <https://de.wikipedia.org/w/index.php?title=Pangramm&oldid=170578983>', 'Pango Language Sample Table'])


add_sample('de', '⠋⠁⠇⠱⠑⠎ ⠳⠃⠑⠝ ⠧⠕⠝ ⠭⠽⠇⠕⠏⠓⠕⠝⠍⠥⠎⠊⠅ ⠟⠥⠜⠇⠞ ⠚⠑⠙⠑⠝ ⠛⠗⠪⠮⠑⠗⠑⠝ ⠵⠺⠑⠗⠛⠄',
           original='Falsches Üben von Xylophonmusik quält jeden größeren Zwerg.',
           english='Wrong practising of xylophone music bothers every larger dwarf.',
           script='Brai', flags=['grade1'], prio=PRIO_WITHHOLD,
           sources=['List of Pangrams, Wikipedia, 12 October 2014 <https://web.archive.org/web/20141012231620/http://en.wikipedia.org/wiki/List_of_pangrams>'])


add_sample('de', '⠋⠒⠱⠿ ⠳⠃⠉ ⠧ ⠠⠭⠠⠽⠇⠕⠏⠓⠕⠝⠍⠅ ⠠⠟⠥⠜⠇⠞ ⠚⠙⠉ ⠐⠛⠮⠻⠉ ⠵⠺⠻⠛⠄',
           original='Falsches Üben von Xylophonmusik quält jeden größeren Zwerg.',
           english='Wrong practising of xylophone music bothers every larger dwarf.',
           script='Brai', flags=['grade2'], prio=PRIO_PREFER,
           sources=['List of Pangrams, Wikipedia, 12 October 2014 <https://web.archive.org/web/20141012231620/http://en.wikipedia.org/wiki/List_of_pangrams>'])


add_sample('de', '⠦⠋⠊⠭⠂ ⠱⠺⠽⠵⠖⠦ ⠟⠥⠜⠅⠞ ⠚⠳⠗⠛⠑⠝ ⠃⠇⠪⠙ ⠧⠕⠍ ⠏⠁⠮⠄',
           original='„Fix, Schwyz!„ quäkt Jürgen blöd vom Paß.',
           english='“Quick, Schwyz!” Jürgen squawks zanily from the pass.',
           script='Brai', flags=['grade1'], prio=PRIO_WITHHOLD,
           sources=['List of Pangrams, Wikipedia, 12 October 2014 <https://web.archive.org/web/20141012231620/http://en.wikipedia.org/wiki/List_of_pangrams>'])


add_sample('de', '⠦⠋⠊⠠⠭⠂ ⠱⠺⠠⠽⠵⠖⠦ ⠠⠟⠥⠜⠅⠞ ⠚⠳⠗⠛⠉ ⠃⠇⠪⠙ ⠧⠍ ⠏⠁⠠⠮⠄',
           original='„Fix, Schwyz!„ quäkt Jürgen blöd vom Paß.',
           english='“Quick, Schwyz!” Jürgen squawks zanily from the pass.',
           script='Brai', flags=['grade2'], prio=PRIO_PREFER,
           sources=['List of Pangrams, Wikipedia, 12 October 2014 <https://web.archive.org/web/20141012231620/http://en.wikipedia.org/wiki/List_of_pangrams>'])


add_sample('ar-ar', '⠝⠯ ⠱⠅⠊⠍ ⠇⠓ ⠎⠗ ⠟⠁⠾⠷ ⠺⠮⠺ ⠩⠌⠝ ⠸⠷ ⠍⠅⠞⠺⠃ ⠕ ⠹⠺⠃ ⠌⠭⠫⠗ ⠺⠍⠣⠇⠋ ⠃⠚⠇⠙ ⠌⠵⠗⠟',
           original='نص حكيم له سر قاطع وذو شأن عظيم مكتوب على ثوب أخضر ومغلف بجلد أزرق',
           english='A wise text with a definite secret and great significance, written on green cloth and wrapped in blue leather.',
           script='Brai', flags=['grade2'], prio=PRIO_PREFER,
           sources=['جامع حروف - ويكيبيديا، الموسوعة الحرة, 17:02، 30 نوفمبر 2017 <https://ar.wikipedia.org/w/index.php?title=%D8%AC%D8%A7%D9%85%D8%B9_%D8%AD%D8%B1%D9%88%D9%81&oldid=25730743>', 'Pango Language Sample Table'])


add_sample('ar-ar', '⠁⠯⠃⠗ ⠕ ⠱⠋⠿ ⠭⠫⠗ ⠺⠁⠲⠩⠗ ⠋⠾⠝⠁⠐ ⠺⠵⠚ ⠻⠅ ⠖ ⠃⠣⠙⠁⠮ ⠴⠹⠍⠧',
           original='اصبر على حفظ خضر واستشر فطنا، وزج همك في بغداذ منثملا',
           english='Be careful to protect the grasses and consult the clever, and put your concerns in a great effort',
           script='Brai', flags=['grade2'], prio=PRIO_PREFER,
           sources=['جامع حروف - ويكيبيديا، الموسوعة الحرة, 17:02، 30 نوفمبر 2017 <https://ar.wikipedia.org/w/index.php?title=%D8%AC%D8%A7%D9%85%D8%B9_%D8%AD%D8%B1%D9%88%D9%81&oldid=25730743>', 'List of Pangrams, Wikipedia, 12 October 2014 <https://web.archive.org/web/20141012231620/http://en.wikipedia.org/wiki/List_of_pangrams>'])


add_sample('ar-ar', '⠓⠧ ⠎⠅⠝⠞ ⠃⠮⠊ ⠫⠣⠹⠔ ⠋⠟⠙ ⠵⠷⠍⠼ ⠄⡳⠭⠆⠴⠂⠲⠄ ⠩⠭⠯⠞ ⠞⠾⠇⠃ ⠿⠃⠊⠁⠆ ⠗⠁⠱ ⠍⠚⠞⠁⠵⠁',
           original='هلا سكنت بذي ضغثٍ فقد زعموا — شخصت تطلب ظبياً راح مجتازا',
           english='Hala calmed down after getting lost - she claimed she proceeded to ask an antelope passing by.',
           script='Brai', flags=['grade2'], prio=PRIO_PREFER,
           sources=['جامع حروف - ويكيبيديا، الموسوعة الحرة, 17:02، 30 نوفمبر 2017 <https://ar.wikipedia.org/w/index.php?title=%D8%AC%D8%A7%D9%85%D8%B9_%D8%AD%D8%B1%D9%88%D9%81&oldid=25730743>', 'List of Pangrams, Wikipedia, 12 October 2014 <https://web.archive.org/web/20141012231620/http://en.wikipedia.org/wiki/List_of_pangrams>'])


add_sample('es', '⠨⠚⠕⠧⠑⠝⠉⠊⠇⠇⠕ ⠑⠍⠏⠕⠝⠵⠕⠻⠁⠙⠕ ⠙⠑ ⠺⠓⠊⠎⠅⠽⠒ ⠖⠟⠥⠮ ⠋⠊⠛⠥⠗⠕⠞⠁ ⠑⠭⠓⠊⠃⠑⠖',
           original='Jovencillo emponzoñado de whisky: ¡qué figurota exhibe!',
           english="Youngster drunk on whiskey — what a figure he's exhibiting!.",
           script='Brai', flags=['grade1'], prio=PRIO_WITHHOLD,
           sources=['Pangrama - Wikipedia, la enciclopedia libre, 16:45 5 abr 2018 <https://es.wikipedia.org/w/index.php?title=Pangrama&oldid=106733458>', 'Pango Language Sample Table'])


add_sample('es', '⠨⠚⠕⠧⠢⠉⠊⠇⠇⠕ ⠣⠏⠭⠵⠕⠻⠹⠕ ⠙ ⠐⠺⠓⠊⠎⠅⠽⠒ ⠖⠐⠟ ⠋⠊⠛⠥⠗⠕⠞⠁ ⠭⠓⠊⠃⠑⠖',
           original='Jovencillo emponzoñado de whisky: ¡qué figurota exhibe!',
           english="Youngster drunk on whiskey — what a figure he's exhibiting!.",
           script='Brai', flags=['grade2'], prio=PRIO_PREFER,
           sources=['Pangrama - Wikipedia, la enciclopedia libre, 16:45 5 abr 2018 <https://es.wikipedia.org/w/index.php?title=Pangrama&oldid=106733458>', 'Pango Language Sample Table'])


add_sample('es', '⠨⠃⠑⠝⠚⠁⠍⠌⠝ ⠏⠊⠙⠊⠬ ⠥⠝⠁ ⠃⠑⠃⠊⠙⠁ ⠙⠑ ⠅⠊⠺⠊ ⠽ ⠋⠗⠑⠎⠁⠄ ⠨⠝⠕⠮⠂ ⠎⠊⠝ ⠧⠑⠗⠛⠳⠑⠝⠵⠁⠂ ⠇⠁ ⠍⠷⠎ ⠑⠭⠟⠥⠊⠎⠊⠞⠁ ⠉⠓⠁⠍⠏⠁⠻⠁ ⠙⠑⠇ ⠍⠑⠝⠾⠄',
           original='Benjamín pidió una bebida de kiwi y fresa. Noé, sin vergüenza, la más exquisita champaña del menú.',
           english='Benjamin asked for a kiwi and strawberry. Noah, without shame, the most exquisite champagne on the menu.',
           script='Brai', flags=['grade1'], prio=PRIO_WITHHOLD,
           sources=['Pangrama - Wikipedia, la enciclopedia libre, 16:45 5 abr 2018 <https://es.wikipedia.org/w/index.php?title=Pangrama&oldid=106733458>'])


add_sample('es', '⠨⠃⠢⠚⠁⠍⠌⠝ ⠏⠊⠙⠊⠬ ⠥⠁ ⠃⠑⠃⠊⠙⠁ ⠙ ⠐⠅⠊⠺⠊ ⠽ ⠋⠗⠫⠁⠄ ⠨⠝⠕⠮⠂ ⠔ ⠧⠦⠛⠳⠢⠵⠁⠂ ⠄ ⠐⠷ ⠭⠟⠊⠎⠊⠞⠁ ⠉⠓⠁⠍⠏⠁⠻⠁ ⠲ ⠍⠢⠾⠄',
           original='Benjamín pidió una bebida de kiwi y fresa. Noé, sin vergüenza, la más exquisita champaña del menú.',
           english='Benjamin asked for a kiwi and strawberry. Noah, without shame, the most exquisite champagne on the menu.',
           script='Brai', flags=['grade2'], prio=PRIO_PREFER,
           sources=['Pangrama - Wikipedia, la enciclopedia libre, 16:45 5 abr 2018 <https://es.wikipedia.org/w/index.php?title=Pangrama&oldid=106733458>'])


add_sample('es', '⠨⠑⠇ ⠧⠑⠇⠕⠵ ⠍⠥⠗⠉⠊⠮⠇⠁⠛⠕ ⠓⠊⠝⠙⠾ ⠉⠕⠍⠌⠁ ⠋⠑⠇⠊⠵ ⠉⠁⠗⠙⠊⠇⠇⠕ ⠽ ⠅⠊⠺⠊⠄ ⠨⠇⠁ ⠉⠊⠛⠳⠑⠻⠁ ⠞⠕⠉⠁⠃⠁ ⠑⠇ ⠎⠁⠭⠕⠋⠬⠝ ⠙⠑⠞⠗⠷⠎ ⠙⠑⠇ ⠏⠁⠇⠑⠝⠟⠥⠑ ⠙⠑ ⠏⠁⠚⠁⠄',
           original='El veloz murciélago hindú comía feliz cardillo y kiwi. La cigüeña tocaba el saxofón detrás del palenque de paja.',
           english='The quick Hindu bat was happily eating golden thistle and kiwi. The stork was playing the saxophone behind the straw arena.',
           script='Brai', flags=['grade1'], prio=PRIO_WITHHOLD,
           sources=['List of Pangrams, Wikipedia, 12 October 2014 <https://web.archive.org/web/20141012231620/http://en.wikipedia.org/wiki/List_of_pangrams>', 'Pangrama - Wikipedia, la enciclopedia libre, 16:45 5 abr 2018 <https://es.wikipedia.org/w/index.php?title=Pangrama&oldid=106733458>'])


add_sample('es', '⠨⠑ ⠧⠑⠇⠕⠵ ⠍⠥⠗⠉⠊⠮⠇⠁⠛⠕ ⠓⠔⠙⠾ ⠉⠺⠌⠁ ⠋⠑⠇⠊⠵ ⠉⠡⠙⠊⠇⠇⠕ ⠽ ⠐⠅⠊⠺⠊⠄ ⠨⠄ ⠉⠊⠛⠳⠑⠻⠁ ⠞⠕⠉⠂⠁ ⠑ ⠐⠎⠁⠭⠕⠋⠬⠝ ⠙⠴ ⠲ ⠏⠅⠢⠟ ⠙ ⠏⠁⠚⠁⠄',
           original='El veloz murciélago hindú comía feliz cardillo y kiwi. La cigüeña tocaba el saxofón detrás del palenque de paja.',
           english='The quick Hindu bat was happily eating golden thistle and kiwi. The stork was playing the saxophone behind the straw arena.',
           script='Brai', flags=['grade2'], prio=PRIO_PREFER,
           sources=['List of Pangrams, Wikipedia, 12 October 2014 <https://web.archive.org/web/20141012231620/http://en.wikipedia.org/wiki/List_of_pangrams>', 'Pangrama - Wikipedia, la enciclopedia libre, 16:45 5 abr 2018 <https://es.wikipedia.org/w/index.php?title=Pangrama&oldid=106733458>'])


add_sample('ru-compbrl', '⠘W QAXAH |GA JIL B! CITRUS⠠⠢ ⠘DA⠂ NO FAL):IW!& {KZEMPL$R⠠⠖',
           original='В чащах юга жил бы цитрус? Да, но фальшивый экземпляр!',
           english='Would a citrus fruit live in the thickets of the south? Yes, but a fake one!',
           script='Brai', flags=[], prio=PRIO_DEFAULT,
           sources=['Панграмма — Википедия, 14:39, 13 апреля 2018 <https://ru.wikipedia.org/w/index.php?title=%D0%9F%D0%B0%D0%BD%D0%B3%D1%80%D0%B0%D0%BC%D0%BC%D0%B0&oldid=92068074>', 'Pango Language Sample Table'])


add_sample('ru-litbrl', 'W QAXAH |GA JIL B! CITRUS⠢ DA⠂NO FAL):IW!& {KZEMPL$R⠖',
           original='В чащах юга жил бы цитрус? Да, но фальшивый экземпляр!',
           english='Would a citrus fruit live in the thickets of the south? Yes, but a fake one!',
           script='Brai', flags=[], prio=PRIO_DEFAULT,
           sources=['Панграмма — Википедия, 14:39, 13 апреля 2018 <https://ru.wikipedia.org/w/index.php?title=%D0%9F%D0%B0%D0%BD%D0%B3%D1%80%D0%B0%D0%BC%D0%BC%D0%B0&oldid=92068074>', 'Pango Language Sample Table'])


add_sample('ru', '⡺ ⠟⠁⠭⠁⠓ ⠳⠛⠁ ⠚⠊⠇ ⠃⠮ ⠉⠊⠞⠗⠥⠎⠹ ⡙⠁⠠ ⠝⠕ ⠋⠁⠇⠾⠱⠊⠺⠮⠯ ⠪⠅⠵⠑⠍⠏⠇⠫⠗⡖',
           original='В чащах юга жил бы цитрус? Да, но фальшивый экземпляр!',
           english='Would a citrus fruit live in the thickets of the south? Yes, but a fake one!',
           script='Brai', flags=[], prio=PRIO_DEFAULT,
           sources=['Панграмма — Википедия, 14:39, 13 апреля 2018 <https://ru.wikipedia.org/w/index.php?title=%D0%9F%D0%B0%D0%BD%D0%B3%D1%80%D0%B0%D0%BC%D0%BC%D0%B0&oldid=92068074>', 'Pango Language Sample Table'])


add_sample('ru-compbrl', '⠘:IROKA$ {LEKTRIFIKACI$ |JN!H GUBERNI& DAST MOXN!& TOLQOK POD(*MU SEL)SKOGO HOZ$&STWA⠲',
           original='Широкая электрификация южных губерний даст мощный толчок подъёму сельского хозяйства.',
           english='Widespread electrification of the Southern provinces will give a powerful push to the rise of agriculture.',
           script='Brai', flags=[], prio=PRIO_DEFAULT,
           sources=['Панграмма — Википедия, 14:39, 13 апреля 2018 <https://ru.wikipedia.org/w/index.php?title=%D0%9F%D0%B0%D0%BD%D0%B3%D1%80%D0%B0%D0%BC%D0%BC%D0%B0&oldid=92068074>', 'List of Pangrams, Wikipedia, 12 October 2014 <https://web.archive.org/web/20141012231620/http://en.wikipedia.org/wiki/List_of_pangrams>'])


add_sample('ru-litbrl', ':IROKA$ {LEKTRIFIKACI$ |JN!H GUBERNI& DAST MOXN!& TOLQOK POD(*MU SEL)SKOGO HOZ$&STWA⠲',
           original='Широкая электрификация южных губерний даст мощный толчок подъёму сельского хозяйства.',
           english='Widespread electrification of the Southern provinces will give a powerful push to the rise of agriculture.',
           script='Brai', flags=[], prio=PRIO_DEFAULT,
           sources=['Панграмма — Википедия, 14:39, 13 апреля 2018 <https://ru.wikipedia.org/w/index.php?title=%D0%9F%D0%B0%D0%BD%D0%B3%D1%80%D0%B0%D0%BC%D0%BC%D0%B0&oldid=92068074>', 'List of Pangrams, Wikipedia, 12 October 2014 <https://web.archive.org/web/20141012231620/http://en.wikipedia.org/wiki/List_of_pangrams>'])


add_sample('ru', '⡱⠊⠗⠕⠅⠁⠫ ⠪⠇⠑⠅⠞⠗⠊⠋⠊⠅⠁⠉⠊⠫ ⠳⠚⠝⠮⠓ ⠛⠥⠃⠑⠗⠝⠊⠯ ⠙⠁⠎⠞ ⠍⠕⠭⠝⠮⠯ ⠞⠕⠇⠟⠕⠅ ⠏⠕⠙⠷⠡⠍⠥ ⠎⠑⠇⠾⠎⠅⠕⠛⠕ ⠓⠕⠵⠫⠯⠎⠞⠺⠁⠨',
           original='Широкая электрификация южных губерний даст мощный толчок подъёму сельского хозяйства.',
           english='Widespread electrification of the Southern provinces will give a powerful push to the rise of agriculture.',
           script='Brai', flags=[], prio=PRIO_DEFAULT,
           sources=['Панграмма — Википедия, 14:39, 13 апреля 2018 <https://ru.wikipedia.org/w/index.php?title=%D0%9F%D0%B0%D0%BD%D0%B3%D1%80%D0%B0%D0%BC%D0%BC%D0%B0&oldid=92068074>', 'List of Pangrams, Wikipedia, 12 October 2014 <https://web.archive.org/web/20141012231620/http://en.wikipedia.org/wiki/List_of_pangrams>'])


add_sample('ru-compbrl', '⠘S(E:) JE EX* {TIH M$GKIH FRANCUZSKIH BULOK⠂ DA W!PE& QA|⠠⠖',
           original='Съешь же ещё этих мягких французских булок, да выпей чаю!',
           english='So eat more of these soft French loaves, and have some tea!',
           script='Brai', flags=[], prio=PRIO_DEFAULT,
           sources=['Панграмма — Википедия, 14:39, 13 апреля 2018 <https://ru.wikipedia.org/w/index.php?title=%D0%9F%D0%B0%D0%BD%D0%B3%D1%80%D0%B0%D0%BC%D0%BC%D0%B0&oldid=92068074>', 'List of Pangrams, Wikipedia, 12 October 2014 <https://web.archive.org/web/20141012231620/http://en.wikipedia.org/wiki/List_of_pangrams>'])


add_sample('ru-litbrl', 'S(E:) JE EX* {TIH M$GKIH FRANCUZSKIH BULOK⠂DA W!PE& QA|⠖',
           original='Съешь же ещё этих мягких французских булок, да выпей чаю!',
           english='So eat more of these soft French loaves, and have some tea!',
           script='Brai', flags=[], prio=PRIO_DEFAULT,
           sources=['Панграмма — Википедия, 14:39, 13 апреля 2018 <https://ru.wikipedia.org/w/index.php?title=%D0%9F%D0%B0%D0%BD%D0%B3%D1%80%D0%B0%D0%BC%D0%BC%D0%B0&oldid=92068074>', 'List of Pangrams, Wikipedia, 12 October 2014 <https://web.archive.org/web/20141012231620/http://en.wikipedia.org/wiki/List_of_pangrams>'])


add_sample('ru', '⡎⠷⠑⠱⠾ ⠚⠑ ⠑⠭⠡ ⠪⠞⠊⠓ ⠍⠫⠛⠅⠊⠓ ⠋⠗⠁⠝⠉⠥⠵⠎⠅⠊⠓ ⠃⠥⠇⠕⠅⠠ ⠙⠁ ⠺⠮⠏⠑⠯ ⠟⠁⠳⡖',
           original='Съешь же ещё этих мягких французских булок, да выпей чаю!',
           english='So eat more of these soft French loaves, and have some tea!',
           script='Brai', flags=[], prio=PRIO_DEFAULT,
           sources=['Панграмма — Википедия, 14:39, 13 апреля 2018 <https://ru.wikipedia.org/w/index.php?title=%D0%9F%D0%B0%D0%BD%D0%B3%D1%80%D0%B0%D0%BC%D0%BC%D0%B0&oldid=92068074>', 'List of Pangrams, Wikipedia, 12 October 2014 <https://web.archive.org/web/20141012231620/http://en.wikipedia.org/wiki/List_of_pangrams>'])


add_sample('tr', '⠠⠏⠊⠚⠁⠍⠁⠇⠔ ⠓⠁⠎⠞⠁ ⠽⠁⠈⠬⠛⠔⠵ ⠘⠯⠎⠕⠋⠘⠒⠕⠗⠑ ⠘⠯⠉⠁⠃⠥⠉⠁⠅ ⠛⠘⠒⠥⠧⠑⠝⠙⠊',
           original='Pijamalı hasta yağız şoföre çabucak güvendi',
           english='The patient in pajamas trusted the swarthy driver quickly',
           script='Brai', flags=['grade1'], prio=PRIO_WITHHOLD,
           sources=['Pangram - Vikipedi, 14.54, 12 Ocak 2017 <https://tr.wikipedia.org/w/index.php?title=Pangram&oldid=18038786>', 'Pango Language Sample Table'])


add_sample('tr', '⠠⠏⠊⠚⠁⠰⠌ ⠒⠎⠾ ⠫⠣⠔⠵ ⠩⠕⠋⠪⠗⠑ ⠡⠁⠆⠘⠻ ⠛⠳⠢⠝⠯',
           original='Pijamalı hasta yağız şoföre çabucak güvendi',
           english='The patient in pajamas trusted the swarthy driver quickly',
           script='Brai', flags=['grade2'], prio=PRIO_PREFER,
           sources=['Pangram - Vikipedi, 14.54, 12 Ocak 2017 <https://tr.wikipedia.org/w/index.php?title=Pangram&oldid=18038786>', 'Pango Language Sample Table'])


add_sample('tr', '⡏⠊⠚⠁⠍⠁⠇⠔ ⠓⠁⠎⠞⠁ ⠽⠁⠣⠔⠵ ⠩⠕⠋⠪⠗⠑ ⠡⠁⠃⠥⠉⠁⠅ ⠛⠳⠧⠑⠝⠙⠊',
           original='Pijamalı hasta yağız şoföre çabucak güvendi',
           english='The patient in pajamas trusted the swarthy driver quickly',
           script='Brai', flags=[], prio=PRIO_DEFAULT,
           sources=['Pangram - Vikipedi, 14.54, 12 Ocak 2017 <https://tr.wikipedia.org/w/index.php?title=Pangram&oldid=18038786>', 'Pango Language Sample Table'])


add_sample('ko-2006', '⠋⠕⠠⠪⠺ ⠈⠥⠩⠨⠥⠈⠎⠒⠪⠒ ⠕⠃⠠⠍⠂⠠⠈⠕⠐⠕ ⠑⠣⠒⠉⠣⠜ ⠚⠣⠈⠥ ⠓⠪⠁⠘⠱⠂⠚⠣⠒ ⠈⠕⠠⠍⠂⠪⠒ ⠙⠕⠂⠬⠰⠕ ⠣⠒⠴⠊⠣',
           original='키스의 고유조건은 입술끼리 만나야 하고 특별한 기술은 필요치 않다',
           english='The unique condition of the kiss is that the lips must meet and no special skills are needed',
           script='Brai', flags=['grade1'], prio=PRIO_WITHHOLD,
           sources=['GNOME', 'The quick brown fox jumps over the lazy dog - 위키백과, 우리 모두의 백과사전, 2018년 1월 27일 (토) 14:50 판 <https://ko.wikipedia.org/w/index.php?title=The_quick_brown_fox_jumps_over_the_lazy_dog&oldid=20572829>'])


add_sample('ko-2006', '⠋⠕⠠⠪⠺ ⠈⠥⠩⠨⠥⠈⠾⠵ ⠕⠃⠠⠯⠠⠈⠕⠐⠕ ⠑⠒⠉⠣⠜ ⠚⠈⠥ ⠓⠪⠁⠘⠳⠚⠒ ⠈⠕⠠⠯⠵ ⠙⠕⠂⠬⠰⠕ ⠣⠒⠴⠊',
           original='키스의 고유조건은 입술끼리 만나야 하고 특별한 기술은 필요치 않다',
           english='The unique condition of the kiss is that the lips must meet and no special skills are needed',
           script='Brai', flags=['grade2'], prio=PRIO_PREFER,
           sources=['GNOME', 'The quick brown fox jumps over the lazy dog - 위키백과, 우리 모두의 백과사전, 2018년 1월 27일 (토) 14:50 판 <https://ko.wikipedia.org/w/index.php?title=The_quick_brown_fox_jumps_over_the_lazy_dog&oldid=20572829>'])


add_sample('ko', '⠋⠕⠠⠪⠺ ⠈⠥⠩⠨⠥⠈⠎⠒⠪⠒ ⠕⠃⠠⠍⠂⠠⠈⠕⠐⠕ ⠑⠣⠒⠉⠣⠜ ⠚⠣⠈⠥ ⠓⠪⠁⠘⠱⠂⠚⠣⠒ ⠈⠕⠠⠍⠂⠪⠒ ⠙⠕⠂⠬⠰⠕ ⠣⠒⠴⠊⠣',
           original='키스의 고유조건은 입술끼리 만나야 하고 특별한 기술은 필요치 않다',
           english='The unique condition of the kiss is that the lips must meet and no special skills are needed',
           script='Brai', flags=['grade1'], prio=PRIO_WITHHOLD,
           sources=['GNOME', 'The quick brown fox jumps over the lazy dog - 위키백과, 우리 모두의 백과사전, 2018년 1월 27일 (토) 14:50 판 <https://ko.wikipedia.org/w/index.php?title=The_quick_brown_fox_jumps_over_the_lazy_dog&oldid=20572829>'])


add_sample('ko', '⠋⠕⠠⠪⠺ ⠈⠥⠩⠨⠥⠈⠾⠵ ⠕⠃⠠⠯⠠⠈⠕⠐⠕ ⠑⠒⠉⠣⠜ ⠚⠈⠥ ⠓⠪⠁⠘⠳⠚⠒ ⠈⠕⠠⠯⠵ ⠙⠕⠂⠬⠰⠕ ⠣⠒⠴⠊',
           original='키스의 고유조건은 입술끼리 만나야 하고 특별한 기술은 필요치 않다',
           english='The unique condition of the kiss is that the lips must meet and no special skills are needed',
           script='Brai', flags=['grade2'], prio=PRIO_PREFER,
           sources=['GNOME', 'The quick brown fox jumps over the lazy dog - 위키백과, 우리 모두의 백과사전, 2018년 1월 27일 (토) 14:50 판 <https://ko.wikipedia.org/w/index.php?title=The_quick_brown_fox_jumps_over_the_lazy_dog&oldid=20572829>'])


add_sample('ko-2006', '⠨⠎⠶ ⠰⠣⠢⠙⠣⠒ ⠜⠶⠘⠣⠒⠊⠗⠁ ⠈⠩⠠⠍ ⠋⠪⠒ ⠈⠬⠨⠣ ⠓⠣⠈⠥ ⠚⠥⠒⠐⠌ ⠰⠕⠐⠪⠒ ⠉⠣⠂',
           original='정 참판 양반댁 규수 큰 교자 타고 혼례 치른 날',
           english='On the day when a marriage ceremony was held with a large jiaozi',
           script='Brai', flags=['grade1'], prio=PRIO_WITHHOLD,
           sources=['The quick brown fox jumps over the lazy dog - 위키백과, 우리 모두의 백과사전, 2018년 1월 27일 (토) 14:50 판 <https://ko.wikipedia.org/w/index.php?title=The_quick_brown_fox_jumps_over_the_lazy_dog&oldid=20572829>', 'google'])


add_sample('ko-2006', '⠨⠻ ⠰⠣⠢⠙⠒ ⠜⠶⠘⠒⠊⠗⠁ ⠈⠩⠠⠍ ⠋⠵ ⠈⠬⠨ ⠓⠈⠥ ⠚⠷⠐⠌ ⠰⠕⠐⠵ ⠉⠂',
           original='정 참판 양반댁 규수 큰 교자 타고 혼례 치른 날',
           english='On the day when a marriage ceremony was held with a large jiaozi',
           script='Brai', flags=['grade2'], prio=PRIO_PREFER,
           sources=['The quick brown fox jumps over the lazy dog - 위키백과, 우리 모두의 백과사전, 2018년 1월 27일 (토) 14:50 판 <https://ko.wikipedia.org/w/index.php?title=The_quick_brown_fox_jumps_over_the_lazy_dog&oldid=20572829>', 'google'])


add_sample('ko', '⠨⠎⠶ ⠰⠣⠢⠙⠣⠒ ⠜⠶⠘⠣⠒⠊⠗⠁ ⠈⠩⠠⠍ ⠋⠪⠒ ⠈⠬⠨⠣ ⠓⠣⠈⠥ ⠚⠥⠒⠐⠌ ⠰⠕⠐⠪⠒ ⠉⠣⠂',
           original='정 참판 양반댁 규수 큰 교자 타고 혼례 치른 날',
           english='On the day when a marriage ceremony was held with a large jiaozi',
           script='Brai', flags=['grade1'], prio=PRIO_WITHHOLD,
           sources=['The quick brown fox jumps over the lazy dog - 위키백과, 우리 모두의 백과사전, 2018년 1월 27일 (토) 14:50 판 <https://ko.wikipedia.org/w/index.php?title=The_quick_brown_fox_jumps_over_the_lazy_dog&oldid=20572829>', 'google'])


add_sample('ko', '⠨⠻ ⠰⠣⠢⠙⠒ ⠜⠶⠘⠒⠊⠗⠁ ⠈⠩⠠⠍ ⠋⠵ ⠈⠬⠨ ⠓⠈⠥ ⠚⠷⠐⠌ ⠰⠕⠐⠵ ⠉⠂',
           original='정 참판 양반댁 규수 큰 교자 타고 혼례 치른 날',
           english='On the day when a marriage ceremony was held with a large jiaozi',
           script='Brai', flags=['grade2'], prio=PRIO_PREFER,
           sources=['The quick brown fox jumps over the lazy dog - 위키백과, 우리 모두의 백과사전, 2018년 1월 27일 (토) 14:50 판 <https://ko.wikipedia.org/w/index.php?title=The_quick_brown_fox_jumps_over_the_lazy_dog&oldid=20572829>', 'google'])


add_sample('ko-2006', '⠊⠣⠐⠣⠢⠨⠍⠗ ⠚⠎⠒ ⠰⠝⠄⠘⠣⠋⠍⠗⠝ ⠓⠣⠈⠥⠙⠣',
           original='다람쥐 헌 쳇바퀴에 타고파',
           english="I wanna ride on the chipmunk's old hamster wheel.",
           script='Brai', flags=['grade1'], prio=PRIO_WITHHOLD,
           sources=['Pango Language Sample Table', 'Sample Font Displays In Other Languages, Wikipedia, The Full Wiki Mirror <http://www.thefullwiki.org/Sample_Font_Displays_In_Other_Languages>'])


add_sample('ko-2006', '⠊⠐⠣⠢⠨⠍⠗ ⠚⠾ ⠰⠝⠄⠘⠋⠍⠗⠝ ⠓⠈⠥⠙',
           original='다람쥐 헌 쳇바퀴에 타고파',
           english="I wanna ride on the chipmunk's old hamster wheel.",
           script='Brai', flags=['grade2'], prio=PRIO_PREFER,
           sources=['Pango Language Sample Table', 'Sample Font Displays In Other Languages, Wikipedia, The Full Wiki Mirror <http://www.thefullwiki.org/Sample_Font_Displays_In_Other_Languages>'])


add_sample('ko', '⠊⠣⠐⠣⠢⠨⠍⠗ ⠚⠎⠒ ⠰⠝⠄⠘⠣⠋⠍⠗⠝ ⠓⠣⠈⠥⠙⠣',
           original='다람쥐 헌 쳇바퀴에 타고파',
           english="I wanna ride on the chipmunk's old hamster wheel.",
           script='Brai', flags=['grade1'], prio=PRIO_WITHHOLD,
           sources=['Pango Language Sample Table', 'Sample Font Displays In Other Languages, Wikipedia, The Full Wiki Mirror <http://www.thefullwiki.org/Sample_Font_Displays_In_Other_Languages>'])


add_sample('ko', '⠊⠐⠣⠢⠨⠍⠗ ⠚⠾ ⠰⠝⠄⠘⠋⠍⠗⠝ ⠓⠈⠥⠙',
           original='다람쥐 헌 쳇바퀴에 타고파',
           english="I wanna ride on the chipmunk's old hamster wheel.",
           script='Brai', flags=['grade2'], prio=PRIO_PREFER,
           sources=['Pango Language Sample Table', 'Sample Font Displays In Other Languages, Wikipedia, The Full Wiki Mirror <http://www.thefullwiki.org/Sample_Font_Displays_In_Other_Languages>'])


add_sample('he', '⠫⠞⠇⢋ ⠁⠧⠟ ⠝⠎ ⠙⠗⢡ ⠍⠵⠛⢝ ⠩⠓⠹⠏⠺⠮⢮ ⠡⠚ ⠭⢍⠲',
           original='עטלף אבק נס דרך מזגן שהתפוצץ כי חם.',
           english="A dust bat ran away through an air conditioner which exploded because it's hot",
           script='Brai', flags=[], prio=PRIO_DEFAULT,
           sources=['פנגרמה – ויקיפדיה, 08.06.18, בשעה 09:00. <https://he.wikipedia.org/w/index.php?title=%D7%A4%D7%A0%D7%92%D7%A8%D7%9E%D7%94&oldid=20163492>'])


add_sample('he', '⠙⠛ ⠎⠟⠗⢝ ⠩⠞ ⠧⠚⢍ ⠍⠁⠺⠡⠵⠧ ⠺⠇⠏⠹⠫ ⠍⠮⠁ ⠭⠧⠗⠓⠲',
           original='דג סקרן שט בים מאוכזב ולפתע מצא חברה.',
           english='A curious fish sailed the sea disappointedly, and suddenly found company',
           script='Brai', flags=[], prio=PRIO_DEFAULT,
           sources=['List of Pangrams, Wikipedia, 12 October 2014 <https://web.archive.org/web/20141012231620/http://en.wikipedia.org/wiki/List_of_pangrams>'])


add_sample('he', '⠍⠝⠫⠺⠇⢝ ⠓⠏⢡ ⠡⢋ ⠭⠮⢮ ⠩⠛⠵⠗ ⠟⠞ ⠁⠚⠧⠙ ⠎⠹⢍⠲',
           original='מנעולן הפך כף חצץ שגזר קט איבד סתם.',
           english='A locksmith turned a tablespoon of gravel that a small fragment had just lost.',
           script='Brai', flags=[], prio=PRIO_DEFAULT,
           sources=['פנגרמה – ויקיפדיה, 08.06.18, בשעה 09:00. <https://he.wikipedia.org/w/index.php?title=%D7%A4%D7%A0%D7%92%D7%A8%D7%9E%D7%94&oldid=20163492>'])


add_sample('he', '⠁⠚⢡ ⠝⠞⠺⠎ ⠫⢍ ⠛⠙ ⠡⢮⠠ ⠓⠵⠟⢝ ⠩⠍⠥⠭⠇⢋ ⠧⠮⠗⠏⠹⢢',
           original='איך נטוס עם גד כץ, הזקן שמֻחלף בצרפת?',
           english='How will we fly with Gad Katz, the old man who is replaced in France?',
           script='Brai', flags=[], prio=PRIO_DEFAULT,
           sources=['פנגרמה – ויקיפדיה, 08.06.18, בשעה 09:00. <https://he.wikipedia.org/w/index.php?title=%D7%A4%D7%A0%D7%92%D7%A8%D7%9E%D7%94&oldid=20163492>'])


add_sample('he', '⠙⠛ ⠎⠟⠗⢝ ⠩⠞ ⠇⠺ ⠧⠚⢍ ⠵⢡ ⠁⢡ ⠇⠏⠹⠫ ⠏⠛⠩ ⠭⠧⠺⠗⠓ ⠝⠭⠍⠙⠓ ⠩⠮⠮⠓ ⠡⢡⠲',
           original='דג סקרן שט לו בים זך אך לפתע פגש חבורה נחמדה שצצה כך.',
           english='A curious fish sailed the sea disappointedly, and suddenly found company',
           script='Brai', flags=[], prio=PRIO_DEFAULT,
           sources=['Pango Language Sample Table', 'List of Pangrams, Wikipedia, 12 October 2014 <https://web.archive.org/web/20141012231620/http://en.wikipedia.org/wiki/List_of_pangrams>'])


add_sample('el', '⠨⠭⠑⠎⠅⠑⠏⠐⠁⠵⠚ ⠞⠜⠝ ⠯⠽⠓⠕⠋⠹⠐⠕⠗⠁ ⠃⠙⠑⠇⠽⠛⠍⠐⠊⠁⠲',
           original='Ξεσκεπάζω την ψυχοφθόρα βδελυγμία.',
           english='I unravel the soul-destroying abomination',
           script='Brai', flags=[], prio=PRIO_DEFAULT,
           sources=['Παντόγραμμα - Βικιπαίδεια, 18:57, 1 Απριλίου 2018 <https://el.wikipedia.org/w/index.php?title=%CE%A0%CE%B1%CE%BD%CF%84%CF%8C%CE%B3%CF%81%CE%B1%CE%BC%CE%BC%CE%B1&oldid=6971942>'])


add_sample('el', '⠨⠹⠐⠑⠇⠩ ⠁⠗⠑⠞⠐⠜ ⠅⠣ ⠞⠐⠕⠇⠍⠜ ⠜ ⠑⠇⠱⠹⠑⠗⠐⠊⠁⠲ ⠶⠨⠁⠝⠙⠗⠐⠑⠁⠎ ⠨⠅⠐⠁⠇⠃⠕⠎⠶',
           original='Θέλει αρετή και τόλμη η ελευθερία. (Ανδρέας Κάλβος)',
           english='Liberty requires virtue and mettle. (Andreas Kalvos)',
           script='Brai', flags=[], prio=PRIO_DEFAULT,
           sources=['Pango Language Sample Table', 'List of Pangrams, Wikipedia, 12 October 2014 <https://web.archive.org/web/20141012231620/http://en.wikipedia.org/wiki/List_of_pangrams>'])


add_sample('sr', '⠨⠋⠊⠚⠥⠡⠑ ⠧⠑⠞⠁⠗ ⠥ ⠱⠊⠃⠣⠥⠂ ⠇⠑⠙⠊ ⠏⠁⠎⠁⠮⠑ ⠊ ⠅⠥⠩⠑ ⠊⠵⠁ ⠫⠊⠓ ⠊ ⠛⠥⠝⠹⠁ ⠥ ⠕⠻⠁⠉⠊⠍⠁⠲',
           original='Фијуче ветар у шибљу, леди пасаже и куће иза њих и гунђа у оџацима.',
           english='Wind whistles in the bushes, the ice passages and the houses behind them, and grumbles in the chimneys.',
           script='Brai', flags=['grade1'], prio=PRIO_WITHHOLD,
           sources=['Панграм — Википедија, слободна енциклопедија, 12:26, 20. март 2017 <https://sr.wikipedia.org/w/index.php?title=%D0%9F%D0%B0%D0%BD%D0%B3%D1%80%D0%B0%D0%BC&oldid=12459258>'])


add_sample('sr', '⠨⠧⠥⠅ ⠨⠫⠑⠛⠕⠱⠥⠒ ⠦⠨⠝⠑ ⠇⠕⠍⠊ ⠻⠁⠃⠑ ⠏⠑⠗⠕⠂ ⠙⠕⠹⠊ ⠞⠊⠩⠥⠂ ⠡⠊⠚⠑ ⠎⠑ ⠋⠁⠉⠑ ⠵⠁⠮⠑⠣⠑⠓⠴⠲',
           original='Вук Његошу: „Не ломи џабе перо, дођи тићу, чије се фаце зажељех”.',
           english='Vuk Njegošu: "Do not break the free feather, coming, whose face I desired".',
           script='Brai', flags=['grade1'], prio=PRIO_WITHHOLD,
           sources=['Панграм — Википедија, слободна енциклопедија, 12:26, 20. март 2017 <https://sr.wikipedia.org/w/index.php?title=%D0%9F%D0%B0%D0%BD%D0%B3%D1%80%D0%B0%D0%BC&oldid=12459258>'])


add_sample('sr', '⠨⠝⠊⠻⠕⠂ ⠡⠑⠮⠫⠊⠧⠕ ⠛⠇⠑⠙⠁⠱ ⠋⠕⠞⠑⠣⠥⠂ ⠁ ⠨⠹⠥⠗⠁ ⠊ ⠨⠍⠊⠅⠁ ⠓⠕⠩⠑ ⠏⠕⠵⠊⠉⠊⠚⠥ ⠎⠑⠃⠊⠲',
           original='Ниџо, чежњиво гледаш фотељу, а Ђура и Мика хоће позицију себи.',
           english='Nidžo, looking at the couch with sadness, while Đura and Mika want a position for themselves.',
           script='Brai', flags=['grade1'], prio=PRIO_WITHHOLD,
           sources=['Панграм — Википедија, слободна енциклопедија, 12:26, 20. март 2017 <https://sr.wikipedia.org/w/index.php?title=%D0%9F%D0%B0%D0%BD%D0%B3%D1%80%D0%B0%D0%BC&oldid=12459258>'])


add_sample('sr', '⠨⠫⠕⠚ ⠏⠣⠁⠡⠅⠕⠍ ⠵⠛⠗⠩⠑⠱ ⠞⠥⠹ ⠘⠉⠙⠂ ⠘⠧⠓⠎⠂ ⠃⠑⠮ ⠋⠊⠇⠻⠁⠝⠲',
           original='Njoj pljačkom zgrćeš tuđ CD, VHS, bež fildžan.',
           english="You rob someone else's CD, VHS, beige coffee cup.",
           script='Brai', flags=['grade1'], prio=PRIO_WITHHOLD,
           sources=['Панграм — Википедија, слободна енциклопедија, 12:26, 20. март 2017 <https://sr.wikipedia.org/w/index.php?title=%D0%9F%D0%B0%D0%BD%D0%B3%D1%80%D0%B0%D0%BC&oldid=12459258>'])


add_sample('sr', '⠨⠡⠑⠱⠩⠑ ⠉⠑⠹⠑⠫⠑ ⠍⠗⠑⠮⠁⠎⠞⠊⠍ ⠻⠁⠅⠕⠍ ⠏⠕⠃⠕⠣⠱⠁⠧⠁ ⠋⠑⠗⠞⠊⠇⠊⠵⠁⠉⠊⠚⠥ ⠛⠑⠝⠎⠅⠊⠓ ⠓⠊⠃⠗⠊⠙⠁⠲',
           original='Чешће цeђење мрeжастим џаком побољшава фертилизацију генских хибрида.',
           english='More frequent filtering through the reticular bag improves fertilization of genetic hybrids.',
           script='Brai', flags=['grade1'], prio=PRIO_WITHHOLD,
           sources=['Pango Language Sample Table', 'Sample Font Displays In Other Languages, Wikipedia, The Full Wiki Mirror <http://www.thefullwiki.org/Sample_Font_Displays_In_Other_Languages>'])


add_sample('sr', '⠨⠡⠑⠱⠩⠑ ⠉⠑⠹⠑⠫⠑ ⠍⠗⠑⠮⠁⠎⠞⠊⠍ ⠻⠁⠅⠕⠍ ⠏⠕⠃⠕⠣⠱⠁⠧⠁ ⠋⠑⠗⠞⠊⠇⠊⠵⠁⠉⠊⠚⠥ ⠛⠑⠝⠎⠅⠊⠓ ⠓⠊⠃⠗⠊⠙⠁⠲',
           original='Češće ceđenje mrežastim džakom poboljšava fertilizaciju genskih hibrida.',
           english='More frequent filtering through the reticular bag improves fertilization of genetic hybrids.',
           script='Brai', flags=['grade1'], prio=PRIO_WITHHOLD,
           sources=['Pango Language Sample Table', 'Sample Font Displays In Other Languages, Wikipedia, The Full Wiki Mirror <http://www.thefullwiki.org/Sample_Font_Displays_In_Other_Languages>'])


add_sample('hr', '⠨⠋⠗⠁⠝⠉ ⠨⠓⠇⠁⠏⠊⠩ ⠎⠍⠚⠑⠱⠞⠁ ⠅⠣⠥⠡ ⠕⠙ ⠛⠧⠕⠮⠹⠁ ⠥⠵ ⠻⠃⠥⠫⠑⠄',
           original='Franc Hlapić smješta ključ od gvožđa uz džbunje.',
           english='Franc Hlapic locates the iron key along the bushes',
           script='Brai', flags=['grade1'], prio=PRIO_WITHHOLD,
           sources=['Pangram – Wikipedija, 30. listopada 2015. u 13:03 <https://hr.wikipedia.org/w/index.php?title=Pangram&oldid=4613487>'])


add_sample('ca', '⠨⠚⠕⠧⠑ ⠭⠑⠋⠂ ⠏⠕⠗⠞⠊ ⠺⠓⠊⠎⠅⠽ ⠁⠍⠃ ⠟⠥⠊⠝⠵⠑ ⠛⠇⠁⠯⠕⠝⠎ ⠙⠄⠓⠊⠙⠗⠕⠛⠑⠝⠂ ⠉⠕⠊⠲',
           original="Jove xef, porti whisky amb quinze glaçons d'hidrogen, coi!",
           english='Young chef, bring whisky with fifteen hydrogen ice cubes, damn!',
           script='Brai', flags=['grade1'], prio=PRIO_WITHHOLD,
           sources=['List of Pangrams, Wikipedia, 12 October 2014 <https://web.archive.org/web/20141012231620/http://en.wikipedia.org/wiki/List_of_pangrams>', 'Pango Language Sample Table'])


add_sample('pt-pt', '⠨⠇⠥⠌⠎ ⠁⠗⠛⠳⠊⠁ ⠫ ⠨⠚⠾⠇⠊⠁ ⠟ ⠠⠦⠆⠁⠯⠪⠱⠂ ⠋⠿⠂ ⠉⠓⠷⠂ ⠬⠭⠊⠙⠕⠂ ⠏⠹⠗⠂ ⠵⠡⠝⠛⠼⠠⠦ ⠑⠗⠁⠍ ⠏⠩ ⠙⠕ ⠏⠞⠛⠄',
           original='Luís argüia à Júlia que «brações, fé, chá, óxido, pôr, zângão» eram palavras do português.',
           english='Luís argued to Júlia that “big arms, faith, tea, oxide, to put, bee” were Portuguese words.',
           script='Brai', flags=['grade2'], prio=PRIO_PREFER,
           sources=['List of Pangrams, Wikipedia, 12 October 2014 <https://web.archive.org/web/20141012231620/http://en.wikipedia.org/wiki/List_of_pangrams>'])


add_sample('pt-pt', '⠨⠧⠑⠚⠁⠍ ⠁ ⠆⠥⠭⠁ ⠙⠁ ⠗⠁⠏⠕⠎⠁ ⠨⠎⠅⠞⠁⠤⠨⠏⠕⠉⠊⠶⠩ ⠑ ⠕ ⠉⠼ ⠋⠑⠇⠊⠵ ⠟ ⠙⠰⠍⠑ ⠄⠛⠁⠇⠁⠙⠕⠄',
           original='Vejam a bruxa da raposa Salta-Pocinhas e o cão feliz que dorme regalado.',
           english='Watch the witch of the Jump-Puddles fox and the happy dog that sleeps delighted.',
           script='Brai', flags=['grade2'], prio=PRIO_PREFER,
           sources=['Pango Language Sample Table', 'Sample Font Displays In Other Languages, Wikipedia, The Full Wiki Mirror <http://www.thefullwiki.org/Sample_Font_Displays_In_Other_Languages>'])


add_sample('ro', '⡋⠥⠍⠑⠛⠣⠝⠙ ⠓⠊⠏⠝⠕⠞⠊⠉ ⠎⠁⠱⠊⠥⠇ ⠁⠵⠧⠣⠗⠇⠑ ⠍⠗⠑⠚⠑ ⠩⠝ ⠃⠡⠇⠪⠊⠲',
           original='Fumegând hipnotic sașiul azvârle mreje în bălți.',
           english='Hypnotically smoking, the cross-eyed man throws fishing nets into ponds.',
           script='Brai', flags=[], prio=PRIO_DEFAULT,
           sources=['List of Pangrams, Wikipedia, 12 October 2014 <https://web.archive.org/web/20141012231620/http://en.wikipedia.org/wiki/List_of_pangrams>', 'Pango Language Sample Table'])


add_sample('ro', '⡍⠥⠵⠊⠉⠕⠇⠕⠛⠡ ⠩⠝ ⠃⠑⠚ ⠧⠣⠝⠙ ⠺⠓⠊⠎⠅⠽ ⠱⠊ ⠞⠑⠟⠥⠊⠇⠁⠂ ⠏⠗⠑⠪ ⠋⠊⠭⠲',
           original='Muzicologă în bej vând whisky și tequila, preț fix.',
           english='Musicologist in beige, sells whisky and tequila, fixed price.',
           script='Brai', flags=[], prio=PRIO_DEFAULT,
           sources=['List of Pangrams, Wikipedia, 12 October 2014 <https://web.archive.org/web/20141012231620/http://en.wikipedia.org/wiki/List_of_pangrams>'])


add_sample('ro', '⡩⠝⠚⠥⠗⠣⠝⠙ ⠏⠊⠪⠊⠛⠡⠊⠁⠞⠂ ⠵⠕⠕⠋⠕⠃⠥⠇ ⠉⠕⠍⠁⠝⠙⠡ ⠧⠑⠭⠁⠞ ⠺⠓⠊⠎⠅⠽ ⠱⠊ ⠞⠑⠟⠥⠊⠇⠁⠲',
           original='Înjurând pițigăiat, zoofobul comandă vexat whisky și tequila.',
           english='Swearing in high pitch, the zoophobic man vexedly ordered whisky and tequila.',
           script='Brai', flags=[], prio=PRIO_DEFAULT,
           sources=['List of Pangrams, Wikipedia, 12 October 2014 <https://web.archive.org/web/20141012231620/http://en.wikipedia.org/wiki/List_of_pangrams>'])


add_sample('eo', '⠨⠑⠳⠕⠮⠁⠝⠻⠕ ⠩⠊⠥⠺⠁⠬⠙⠑⠲',
           original='Eĥoŝanĝo ĉiuĵaŭde.',
           english='Change of echo every Thursday',
           script='Brai', flags=['grade1'], prio=PRIO_WITHHOLD,
           sources=['List of Pangrams, Wikipedia, 12 October 2014 <https://web.archive.org/web/20141012231620/http://en.wikipedia.org/wiki/List_of_pangrams>', 'Pango Language Sample Table'])


add_sample('no-no', '⠠⠓⠪⠧⠙⠊⠝⠛⠑⠝⠎ ⠅⠚⠜⠗⠑ ⠎⠟⠥⠁⠺ ⠋⠡⠗ ⠇⠊⠞⠞ ⠏⠊⠵⠵⠁ ⠊ ⠠⠍⠑⠭⠊⠉⠕ ⠃⠽⠄',
           original='Høvdingens kjære squaw får litt pizza i Mexico by.',
           english="The chief's dear squaw gets a little pizza in Mexico City",
           script='Brai', flags=['grade1'], prio=PRIO_WITHHOLD,
           sources=['List of Pangrams, Wikipedia, 12 October 2014 <https://web.archive.org/web/20141012231620/http://en.wikipedia.org/wiki/List_of_pangrams>'])


add_sample('no-no', '⠠⠓⠪⠧⠙⠊⠝⠛⠣⠎ ⠅⠚⠜⠷ ⠎⠟⠥⠁⠺ ⠋⠡⠗ ⠇⠊⠞⠞ ⠏⠊⠵⠵⠁ ⠊ ⠠⠍⠑⠭⠊⠉⠕ ⠃⠽⠄',
           original='Høvdingens kjære squaw får litt pizza i Mexico by.',
           english="The chief's dear squaw gets a little pizza in Mexico City",
           script='Brai', flags=['grade2'], prio=PRIO_PREFER,
           sources=['List of Pangrams, Wikipedia, 12 October 2014 <https://web.archive.org/web/20141012231620/http://en.wikipedia.org/wiki/List_of_pangrams>'])


add_sample('no-no', '⠠⠓⠪⠧⠙⠒⠊⠣⠎ ⠅⠚⠜⠷ ⠎⠟⠥⠁⠺ ⠋⠡⠗ ⠇⠊⠞⠞ ⠏⠊⠵⠵⠁ ⠊ ⠠⠍⠑⠭⠊⠉⠕ ⠃⠽⠄',
           original='Høvdingens kjære squaw får litt pizza i Mexico by.',
           english="The chief's dear squaw gets a little pizza in Mexico City",
           script='Brai', flags=['grade3'], prio=PRIO_PREFER,
           sources=['List of Pangrams, Wikipedia, 12 October 2014 <https://web.archive.org/web/20141012231620/http://en.wikipedia.org/wiki/List_of_pangrams>'])


add_sample('no-no', '⠠⠧⠡⠗ ⠎⠜⠗⠑ ⠠⠵⠥⠇⠥ ⠋ ⠃⠁⠙⠑⠪⠽⠁ ⠎⠏⠊⠇⠞⠑ ⠚⠕ ⠺⠓⠊⠎⠞ ⠉ ⠟⠥⠊⠉⠅⠎⠞⠑⠏ ⠊ ⠍⠊⠝ ⠞⠁⠭⠊⠄',
           original='Vår sære Zulu fra badeøya spilte jo whist og quickstep i min taxi.',
           english='Our strange Zulu from the bathing Island did actually play whist and quickstep in my cab.',
           script='Brai', flags=['grade1'], prio=PRIO_WITHHOLD,
           sources=['List of Pangrams, Wikipedia, 12 October 2014 <https://web.archive.org/web/20141012231620/http://en.wikipedia.org/wiki/List_of_pangrams>', 'Pango Language Sample Table'])


add_sample('no-no', '⠠⠧⠡⠗ ⠎⠜⠷ ⠠⠵⠥⠇⠥ ⠋ ⠃⠁⠙⠑⠪⠽⠁ ⠎⠏⠊⠇⠳ ⠚⠕ ⠺⠓⠊⠎⠞ ⠉ ⠟⠥⠊⠉⠅⠎⠞⠑⠏ ⠊ ⠍⠝ ⠞⠁⠭⠊⠄',
           original='Vår sære Zulu fra badeøya spilte jo whist og quickstep i min taxi.',
           english='Our strange Zulu from the bathing Island did actually play whist and quickstep in my cab.',
           script='Brai', flags=['grade2'], prio=PRIO_PREFER,
           sources=['List of Pangrams, Wikipedia, 12 October 2014 <https://web.archive.org/web/20141012231620/http://en.wikipedia.org/wiki/List_of_pangrams>', 'Pango Language Sample Table'])


add_sample('no-no', '⠠⠧⠡⠗ ⠎⠜⠷ ⠠⠵⠥⠇⠥ ⠋ ⠃⠁⠙⠑⠪⠽⠁ ⠖⠊⠇⠳ ⠚⠕ ⠺⠓⠊⠎⠞ ⠉ ⠟⠥⠊⠉⠅⠎⠞⠑⠏ ⠊ ⠍⠝ ⠞⠁⠭⠊⠄',
           original='Vår sære Zulu fra badeøya spilte jo whist og quickstep i min taxi.',
           english='Our strange Zulu from the bathing Island did actually play whist and quickstep in my cab.',
           script='Brai', flags=['grade3'], prio=PRIO_PREFER,
           sources=['List of Pangrams, Wikipedia, 12 October 2014 <https://web.archive.org/web/20141012231620/http://en.wikipedia.org/wiki/List_of_pangrams>', 'Pango Language Sample Table'])


add_sample('no-no', '⠠⠣ ⠛⠕⠙ ⠎⠞⠊⠇ ⠍⠡ ⠋⠪⠗⠎⠞ ⠉ ⠋⠗⠑⠍⠎⠞ ⠜ ⠅⠇⠼⠄ ⠠⠙⠣ ⠍⠡ ⠜ ⠏⠁⠎⠎⠣⠹⠄ ⠠⠁⠗⠊⠎⠞⠕⠞⠑⠇⠑⠎⠄',
           original='En god stil må først og fremst være klar. Den må være passende. Aristoteles.',
           english='A good essay must first and foremost be clear. It must be appropriate. Aristotle.',
           script='Brai', flags=['grade1'], prio=PRIO_WITHHOLD,
           sources=['List of Pangrams, Wikipedia, 12 October 2014 <https://web.archive.org/web/20141012231620/http://en.wikipedia.org/wiki/List_of_pangrams>'])


add_sample('no-no', '⠠⠣ ⠛⠕⠙ ⠎⠞⠊⠇ ⠍⠡ ⠋⠎⠞ ⠉ ⠋⠗⠑⠍⠎⠞ ⠜ ⠅⠇⠼⠄ ⠠⠙⠣ ⠍⠡ ⠜ ⠏⠁⠎⠎⠣⠹⠄ ⠠⠁⠗⠊⠎⠞⠕⠞⠑⠇⠑⠎⠄',
           original='En god stil må først og fremst være klar. Den må være passende. Aristoteles.',
           english='A good essay must first and foremost be clear. It must be appropriate. Aristotle.',
           script='Brai', flags=['grade2'], prio=PRIO_PREFER,
           sources=['List of Pangrams, Wikipedia, 12 October 2014 <https://web.archive.org/web/20141012231620/http://en.wikipedia.org/wiki/List_of_pangrams>'])


add_sample('no-no', '⠠⠣ ⠛⠕⠙ ⠴⠊⠇ ⠍⠡ ⠋⠉⠋ ⠜ ⠅⠇⠼⠄ ⠠⠙⠣ ⠍⠡ ⠜ ⠏⠁⠎⠎⠣⠹⠄ ⠠⠁⠗⠊⠎⠞⠕⠞⠑⠇⠑⠎⠄',
           original='En god stil må først og fremst være klar. Den må være passende. Aristoteles.',
           english='A good essay must first and foremost be clear. It must be appropriate. Aristotle.',
           script='Brai', flags=['grade3'], prio=PRIO_PREFER,
           sources=['List of Pangrams, Wikipedia, 12 October 2014 <https://web.archive.org/web/20141012231620/http://en.wikipedia.org/wiki/List_of_pangrams>'])


add_sample('is', '⡅⠜⠍⠊ ⠝⠯ ⠪⠭⠊ ⠓⠮⠗ ⠽⠅⠊⠎⠞ ⠫⠚⠹⠋⠥⠍ ⠝⠻ ⠃⠜⠱⠊ ⠧⠣⠇ ⠕⠛ ⠡⠙⠗⠑⠏⠁⠄',
           original='Kæmi ný öxi hér ykist þjófum nú bæði víl og ádrepa.',
           english='If a new axe were here, thieves would feel increasing deterrence and punishment.',
           script='Brai', flags=[], prio=PRIO_DEFAULT,
           sources=['List of Pangrams, Wikipedia, 12 October 2014 <https://web.archive.org/web/20141012231620/http://en.wikipedia.org/wiki/List_of_pangrams>', 'Pango Language Sample Table'])


add_sample('is', '⡎⠧⠕ ⠓⠪⠇⠞⠂ ⠽⠭⠝⠁ ⠅⠯⠗ ⠫⠑⠛⠱⠊ ⠚⠻ ⠥⠍ ⠙⠹⠏ ⠣ ⠋⠮ ⠡ ⠃⠜⠄',
           original='Svo hölt, yxna kýr þegði jú um dóp í fé á bæ.',
           english='A cow in heat with such a limp would admittedly keep silent about drugs in sheep on a farm.',
           script='Brai', flags=[], prio=PRIO_DEFAULT,
           sources=['List of Pangrams, Wikipedia, 12 October 2014 <https://web.archive.org/web/20141012231620/http://en.wikipedia.org/wiki/List_of_pangrams>'])


add_sample('is', '⡫⠻ ⠙⠁⠵⠞ ⠡ ⠓⠝⠮⠱ ⠣ ⠧⠪⠅ ⠕⠛ ⠽⠋⠊⠗ ⠃⠇⠹⠍ ⠎⠑⠭⠯ ⠏⠜⠚⠥⠄',
           original='Þú dazt á hnéð í vök og yfir blóm sexý pæju.',
           english='You fell on the knee in a hole in the ice and over a sexy girl’s flower.',
           script='Brai', flags=[], prio=PRIO_DEFAULT,
           sources=['List of Pangrams, Wikipedia, 12 October 2014 <https://web.archive.org/web/20141012231620/http://en.wikipedia.org/wiki/List_of_pangrams>'])


add_sample('da-lt', '⡟⠥⠊⠵⠙⠑⠇⠞⠁⠛⠑⠗⠝⠑ ⠎⠏⠊⠎⠞⠑ ⠚⠕⠗⠙⠃⠜⠗ ⠍⠑⠙ ⠋⠇⠪⠙⠑⠂ ⠍⠑⠝⠎ ⠉⠊⠗⠅⠥⠎⠅⠇⠕⠧⠝⠑⠝ ⡺⠁⠇⠞⠓⠑⠗ ⠎⠏⠊⠇⠇⠑⠙⠑ ⠏⠡ ⠭⠽⠇⠕⠋⠕⠝⠄',
           original='Quizdeltagerne spiste jordbær med fløde, mens cirkusklovnen Walther spillede på xylofon.',
           english='The quiz contestants ate strawberries with cream while Walther the clown was playing the xylophone.',
           script='Brai', flags=[], prio=PRIO_DEFAULT,
           sources=['List of Pangrams, Wikipedia, 12 October 2014 <https://web.archive.org/web/20141012231620/http://en.wikipedia.org/wiki/List_of_pangrams>', 'Pango Language Sample Table'])


add_sample('hu-hu', '⠨⠑⠹ ⠓⠾⠞⠇⠑⠝ ⠧⠑⠚⠡⠞ ⠋⠷⠇⠟⠝⠩⠌⠏⠻⠂ ⠙⠷⠓⠟⠎ ⠍⠑⠭⠊⠅⠪⠊ ⠬⠗ ⠨⠺⠑⠎⠎⠑⠇⠡⠫⠊⠝⠡⠇ ⠍⠈⠣⠕⠇ ⠨⠯⠥⠊⠞⠪⠃⠁⠝⠄',
           original='Egy hűtlen vejét fülöncsípő, dühös mexikói úr Wesselényinél mázol Quitóban.',
           english="An angry Mexican man, who caught his faithless son-in-law, is painting Wesselényi's house in Quito.",
           script='Brai', flags=['grade1'], prio=PRIO_WITHHOLD,
           sources=['List of Pangrams, Wikipedia, 12 October 2014 <https://web.archive.org/web/20141012231620/http://en.wikipedia.org/wiki/List_of_pangrams>', 'Pango Language Sample Table', 'Pangramma - Wikipédia, 2017. február 17., 16:41 <https://hu.wikipedia.org/w/index.php?title=Pangramma&oldid=18451372>'])


add_sample('hu-hu', '⠑⠹ ⠓⠾⠞⠇⠑⠝ ⠧⠑⠚⠡⠞ ⠋⠷⠇⠟⠝⠩⠌⠏⠻⠂⠙⠷⠓⠟⠎ ⠍⠑⠭⠊⠅⠪⠊ ⠬⠗ ⠺⠑⠎⠎⠑⠇⠡⠫⠊⠝⠡⠇ ⠍⠈⠣⠕⠇ ⠯⠥⠊⠞⠪⠃⠄',
           original='Egy hűtlen vejét fülöncsípő, dühös mexikói úr Wesselényinél mázol Quitóban.',
           english="An angry Mexican man, who caught his faithless son-in-law, is painting Wesselényi's house in Quito.",
           script='Brai', flags=['grade2'], prio=PRIO_PREFER,
           sources=['List of Pangrams, Wikipedia, 12 October 2014 <https://web.archive.org/web/20141012231620/http://en.wikipedia.org/wiki/List_of_pangrams>', 'Pango Language Sample Table', 'Pangramma - Wikipédia, 2017. február 17., 16:41 <https://hu.wikipedia.org/w/index.php?title=Pangramma&oldid=18451372>'])


add_sample('hu-hu', '⠨⠚⠈⠍⠃⠕⠗ ⠉⠡⠇⠬⠂ ⠟⠧ ⠷⠹⠾ ⠑⠭⠤⠯⠺⠁⠝ ⠅⠊ ⠙⠪⠤⠎ ⠋⠻⠣⠂ ⠏⠥⠓⠌⠞⠄',
           original='Jámbor célú, öv ügyű ex-qwan ki dó-s főz, puhít.',
           english='He is a ex-qwan-ki-do player with a belt who cooks and softens.',
           script='Brai', flags=['grade1'], prio=PRIO_WITHHOLD,
           sources=['Pangramma - Wikipédia, 2017. február 17., 16:41 <https://hu.wikipedia.org/w/index.php?title=Pangramma&oldid=18451372>'])


add_sample('hu-hu', '⠚⠈⠍⠃⠕⠗ ⠉⠡⠇⠬⠂⠟⠧ ⠷⠹⠾ ⠑⠭⠤⠯⠺⠁⠝ ⠅⠊ ⠙⠪⠤⠎ ⠋⠻⠣⠂⠏⠥⠓⠌⠞⠄',
           original='Jámbor célú, öv ügyű ex-qwan ki dó-s főz, puhít.',
           english='He is a ex-qwan-ki-do player with a belt who cooks and softens.',
           script='Brai', flags=['grade2'], prio=PRIO_PREFER,
           sources=['Pangramma - Wikipédia, 2017. február 17., 16:41 <https://hu.wikipedia.org/w/index.php?title=Pangramma&oldid=18451372>'])


add_sample('hu-hu', '⠨⠏⠈⠇ ⠋⠕⠹⠪ ⠨⠨⠊⠯⠤⠚⠬ ⠅⠥⠝ ⠑⠭⠧⠻⠂ ⠌⠍ ⠙⠷⠓⠟⠎ ⠁ ⠨⠨⠺⠉ ⠃⠾⠣⠡⠗⠞⠄',
           original='Pál fogyó IQ-jú kun exvő, ím dühös a WC bűzért.',
           english="Paul is spending IQ when I'm leaving angry at the toilet smell.",
           script='Brai', flags=['grade1'], prio=PRIO_WITHHOLD,
           sources=['Pangramma - Wikipédia, 2017. február 17., 16:41 <https://hu.wikipedia.org/w/index.php?title=Pangramma&oldid=18451372>'])


add_sample('hu-hu', '⠏⠈⠇ ⠋⠕⠹⠪ ⠨⠊⠯⠤⠚⠬ ⠅⠥⠝ ⠑⠭⠧⠻⠂⠌⠍ ⠙⠷⠓⠟⠎ ⠂⠨⠺⠉ ⠃⠾⠣⠡⠗⠞⠄',
           original='Pál fogyó IQ-jú kun exvő, ím dühös a WC bűzért.',
           english="Paul is spending IQ when I'm leaving angry at the toilet smell.",
           script='Brai', flags=['grade2'], prio=PRIO_PREFER,
           sources=['Pangramma - Wikipédia, 2017. február 17., 16:41 <https://hu.wikipedia.org/w/index.php?title=Pangramma&oldid=18451372>'])


add_sample('fi-fi', '⡁⠇⠃⠑⠗⠞ ⠕⠎⠞⠊ ⠋⠁⠛⠕⠞⠊⠝ ⠚⠁ ⠞⠪⠗⠜⠽⠞⠞⠊ ⠏⠥⠓⠅⠥⠧⠁⠝ ⠍⠑⠇⠕⠙⠊⠁⠝⠄',
           original='Albert osti fagotin ja töräytti puhkuvan melodian.',
           english='Albert bought a bassoon and blasted a puffing melody.',
           script='Brai', flags=[], prio=PRIO_DEFAULT,
           sources=['List of Pangrams, Wikipedia, 12 October 2014 <https://web.archive.org/web/20141012231620/http://en.wikipedia.org/wiki/List_of_pangrams>'])


add_sample('fi-fi', '⡕⠝ ⠎⠁⠝⠛⠑⠝ ⠓⠁⠥⠎⠅⠁⠁⠂ ⠑⠞⠞⠜ ⠏⠕⠇⠅⠥⠏⠽⠪⠗⠜ ⠕⠝ ⠍⠁⠁⠝⠞⠑⠊⠙⠑⠝ ⠚⠕⠅⠁⠏⠜⠊⠧⠜⠊⠝⠑⠝ ⠊⠇⠍⠊⠪⠄',
           original='On sangen hauskaa, että polkupyörä on maanteiden jokapäiväinen ilmiö.',
           english="It's very funny that a bicycle is a daily road phenomenon",
           script='Brai', flags=[], prio=PRIO_DEFAULT,
           sources=['Pangrammi - Wikipedia, 15. huhtikuuta 2018 kello 12.35 <https://fi.wikipedia.org/w/index.php?title=Pangrammi&oldid=17239063>'])


add_sample('fi-fi', '⡑⠗⠜⠜⠝⠜ ⠚⠜⠜⠞⠜⠧⠜⠝⠜ ⠚⠁ ⠏⠊⠍⠑⠜⠝⠜ ⠽⠪⠝⠜ ⠛⠕⠗⠊⠇⠇⠁ ⠗⠁⠞⠅⠁⠊⠎⠊ ⠎⠥⠙⠕⠅⠥⠝ ⠅⠁⠓⠙⠑⠎⠎⠁ ⠍⠊⠝⠥⠥⠞⠊⠎⠎⠁⠄',
           original='Eräänä jäätävänä ja pimeänä yönä gorilla ratkaisi sudokun kahdessa minuutissa.',
           english='In one of the dark freezing nights, the gorilla solved the sudoku in under two minutes.',
           script='Brai', flags=[], prio=PRIO_DEFAULT,
           sources=['Pangrammi - Wikipedia, 15. huhtikuuta 2018 kello 12.35 <https://fi.wikipedia.org/w/index.php?title=Pangrammi&oldid=17239063>'])


add_sample('fi-fi', '⡧⠊⠑⠅⠁⠎ ⠅⠑⠞⠞⠥ ⠏⠥⠝⠁⠞⠥⠗⠅⠅⠊ ⠇⠁⠊⠎⠅⠁⠝ ⠅⠕⠊⠗⠁⠝ ⠞⠁⠅⠁⠁ ⠅⠥⠗⠅⠅⠊⠄',
           original='Viekas kettu punaturkki laiskan koiran takaa kurkki.',
           english='The cunning red-coated fox peeped from behind the lazy dog.',
           script='Brai', flags=[], prio=PRIO_DEFAULT,
           sources=['List of Pangrams, Wikipedia, 12 October 2014 <https://web.archive.org/web/20141012231620/http://en.wikipedia.org/wiki/List_of_pangrams>', 'Pango Language Sample Table'])


add_sample('fi-fi', '⡞⠪⠗⠅⠽⠇⠑⠍⠏⠊⠚⠜⠧⠕⠝⠛⠁⠓⠙⠥⠎⠄',
           original='Törkylempijävongahdus.',
           english='Muckysnogger booty-call.',
           script='Brai', flags=[], prio=PRIO_DEFAULT,
           sources=['List of Pangrams, Wikipedia, 12 October 2014 <https://web.archive.org/web/20141012231620/http://en.wikipedia.org/wiki/List_of_pangrams>', 'Pangrammi - Wikipedia, 15. huhtikuuta 2018 kello 12.35 <https://fi.wikipedia.org/w/index.php?title=Pangrammi&oldid=17239063>'])


add_sample('et', '⡎⠑⠑ ⠧⠜⠊⠅⠑ ⠍⠪⠇⠙⠑⠗ ⠚⠮⠥⠁⠃ ⠗⠕⠝⠛⠊⠇⠑ ⠓⠳⠏⠁⠞⠁⠲',
           original='See väike mölder jõuab rongile hüpata.',
           english='This small miller is able to jump to train.',
           script='Brai', flags=[], prio=PRIO_DEFAULT,
           sources=['List of Pangrams, Wikipedia, 12 October 2014 <https://web.archive.org/web/20141012231620/http://en.wikipedia.org/wiki/List_of_pangrams>', 'Pango Language Sample Table'])


add_sample('et', '⡚⠥⠃⠑⠙⠁⠇⠞ ⠍⠪⠊⠗⠛⠁⠧ ⠇⠮⠥⠅⠕⠑⠗ ⠓⠳⠏⠏⠁⠎ ⠞⠜⠝⠁⠧⠁⠇⠲',
           original='Jubedalt möirgav lõukoer hüppas tänaval.',
           english='Terribly roaring lion jumped on street.',
           script='Brai', flags=[], prio=PRIO_DEFAULT,
           sources=['List of Pangrams, Wikipedia, 12 October 2014 <https://web.archive.org/web/20141012231620/http://en.wikipedia.org/wiki/List_of_pangrams>'])


add_sample('et', '⡏⠮⠙⠥⠗ ⡵⠁⠛⠗⠑⠃⠊ ⠞⠄ ⠭⢚⢁⢋⢁⠄⠑⠇⠇⠕⠍⠜⠝⠛⠊⠚⠁⠤⠋⠪⠇⠚⠑⠞⠕⠝⠊⠎⠞ ⡉⠊⠟⠕ ⠅⠳⠇⠍⠑⠞⠁⠎ ⠅⠑⠓⠧⠁⠎ ⠛⠁⠗⠁⠁⠄ ⠭⢚⢁⢛⠑⠄⠊⠎⠲',
           original='Põdur Zagrebi tšellomängija-följetonist Ciqo külmetas kehvas garaažis.',
           english='Ill-healthy cellist-feuilletonist Ciqo from Zagreb was being cold in a poor garage.',
           script='Brai', flags=[], prio=PRIO_DEFAULT,
           sources=['List of Pangrams, Wikipedia, 12 October 2014 <https://web.archive.org/web/20141012231620/http://en.wikipedia.org/wiki/List_of_pangrams>'])


add_sample('lt', '⡪⠇⠊⠝⠅⠙⠁⠍⠁ ⠋⠑⠉⠓⠞⠥⠕⠞⠕⠚⠕ ⠮⠏⠁⠛⠁ ⠎⠥⠃⠇⠽⠅⠩⠊⠕⠚⠥⠎⠊ ⠏⠗⠁⠛⠗⠱⠣⠜ ⠁⠏⠧⠁⠇⠬ ⠁⠗⠃⠳⠵⠡ ',
           original='Įlinkdama fechtuotojo špaga sublykčiojusi pragręžė apvalų arbūzą ',
           english='Incurving fencer sword sparkled and perforated a round watermelon',
           script='Brai', flags=[], prio=PRIO_DEFAULT,
           sources=['Pango Language Sample Table', 'List of Pangrams, Wikipedia, 12 October 2014 <https://web.archive.org/web/20141012231620/http://en.wikipedia.org/wiki/List_of_pangrams>'])


add_sample('cs', '⠠⠏⠺⠌⠇⠊⠱ ⠮⠇⠥⠳⠕⠥⠩⠅⠯ ⠅⠾⠫ ⠬⠏⠣⠇ ⠹⠡⠃⠑⠇⠎⠅⠜ ⠪⠙⠽⠄',
           original='Příliš žluťoučký kůň úpěl ďábelské ódy.',
           english='A horse which was too yellow moaned devilish odes.',
           script='Brai', flags=['grade1'], prio=PRIO_WITHHOLD,
           sources=['Pango Language Sample Table', 'List of Pangrams, Wikipedia, 12 October 2014 <https://web.archive.org/web/20141012231620/http://en.wikipedia.org/wiki/List_of_pangrams>'])


add_sample('cs', '⠠⠩⠑⠗⠧⠑⠝⠯ ⠎⠞⠺⠌⠵⠇⠌⠩⠑⠅ ⠁ ⠱⠏⠊⠝⠁⠧⠡ ⠮⠇⠾⠧⠁ ⠹⠕⠃⠁⠇⠊ ⠱⠳⠁⠧⠝⠁⠞⠜ ⠕⠉⠬⠝⠽⠄',
           original='Červený střízlíček a špinavá žlůva ďobali šťavnaté ocúny.',
           english='Small red wren and a dirty oriole picked juicy autumn crocus.',
           script='Brai', flags=['grade1'], prio=PRIO_WITHHOLD,
           sources=['List of Pangrams, Wikipedia, 12 October 2014 <https://web.archive.org/web/20141012231620/http://en.wikipedia.org/wiki/List_of_pangrams>'])


add_sample('cs', '⠠⠵⠧⠇⠡⠱⠳ ⠵⠡⠅⠑⠺⠝⠯ ⠥⠩⠑⠫ ⠎ ⠹⠕⠇⠌⠩⠅⠽ ⠃⠣⠮⠌ ⠏⠕⠙⠜⠇ ⠵⠪⠝⠽ ⠬⠇⠾ ',
           original='Zvlášť zákeřný učeň s ďolíčky běží podél zóny úlů ',
           english='An exceptionally insidious pupil with dimples runs along the beehive zone',
           script='Brai', flags=['grade1'], prio=PRIO_WITHHOLD,
           sources=['List of Pangrams, Wikipedia, 12 October 2014 <https://web.archive.org/web/20141012231620/http://en.wikipedia.org/wiki/List_of_pangrams>'])


add_sample('sk', '⠠⠅⠷⠙⠑⠸ ⠱⠳⠁⠎⠞⠝⠯⠉⠓ ⠹⠁⠞⠸⠕⠧ ⠥⠩⠌ ⠏⠗⠊ ⠬⠎⠞⠌ ⠠⠧⠡⠓⠥ ⠍⠨⠅⠧⠑⠓⠕ ⠅⠕⠫⠁ ⠕⠃⠓⠗⠯⠵⠁⠳ ⠅⠾⠗⠥ ⠁ ⠮⠗⠁⠳ ⠩⠑⠗⠎⠞⠧⠜ ⠍⠈⠎⠕⠲',
           original='Kŕdeľ šťastných ďatľov učí pri ústí Váhu mĺkveho koňa obhrýzať kôru a žrať čerstvé mäso.',
           english='A flock of happy woodpeckers by the mouth of the river Vah is teaching a silent horse to nibble on bark and feed on fresh meat.',
           script='Brai', flags=['grade1'], prio=PRIO_WITHHOLD,
           sources=['List of Pangrams, Wikipedia, 12 October 2014 <https://web.archive.org/web/20141012231620/http://en.wikipedia.org/wiki/List_of_pangrams>'])


add_sample('hy', '⡏⠽⠇ ⠹⠣⠱⠁⠛⠊ ⠬⠁⠭ ⠜⠁⠍⠝ ⠕⠋ ⠁⠵⠟⠪⠺⠞⠱⠁⠝⠥ ⠮⠃⠁⠓⠁⠝⠉ ⠡⠚⠩⠙⠁⠌ ⠧⠝⠁⠎ ⠑⠗ ⠯ ⠫⠁⠻⠅⠄  ⢚⢑⢓⢊⠄',
           original='Բել դղյակի ձախ ժամն օֆ ազգությանը ցպահանջ չճշտած վնաս էր և փառք։',
           english="During our time at the Bel's Castle there was an unspecified loss of honor and glory.",
           script='Brai', flags=[], prio=PRIO_DEFAULT,
           sources=['Font Testing Page by impallari, 8 May 2017 <https://github.com/impallari/Font-Testing-Page/tree/21a03e251623764771ada80b98036d3cd04bc294>'])


add_sample('hy', '⡁⠞⠽⠝⠁⠎ ⠁⠎⠙⠧⠁⠌⠪⠺⠓⠊⠝ ⠇⠪⠣⠁⠮⠽⠇ ⠑ ⡧⠪⠺⠇⠊⠎⠍⠽⠝⠊ ⠇⠚⠪⠺⠍⠄  ⢚⢑⢓⢊⠄',
           original='Աթենաս աստվածուհին լողացել է Վուլիսմենի լճում։',
           english='Goddess Athena swam in lake Voulismeni',
           script='Brai', flags=[], prio=PRIO_DEFAULT,
           sources=['Կրետե - Վիքիպեդիա՝ ազատ հանրագիտարան, 14:47, 12 Դեկտեմբերի 2016 <https://hy.wikipedia.org/w/index.php?title=%D4%BF%D6%80%D5%A5%D5%BF%D5%A5&oldid=4737063>'])


add_sample('hy', '⡵⠯⠎ ⠁⠎⠙⠧⠁⠌⠥ ⡛⠗⠽⠙⠽⠪⠺⠍ ⠩⠁⠝⠞⠁⠓⠁⠗⠽⠮ ⠛⠣⠵⠊⠝ ⠁⠓⠁⠏⠽⠛⠪⠣ ⠓⠎⠛⠁ ⠍⠪⠣⠽⠎⠊⠝⠄  ⢚⢑⢓⢊⠄',
           original='Զևս աստվածը Կրետեում շանթահարեց կղզին ահաբեկող հսկա մողեսին։',
           english='Zeus crushed the gigantic lizard that terrorized the island in Crete.',
           script='Brai', flags=[], prio=PRIO_DEFAULT,
           sources=['Կրետե - Վիքիպեդիա՝ ազատ հանրագիտարան, 14:47, 12 Դեկտեմբերի 2016 <https://hy.wikipedia.org/w/index.php?title=%D4%BF%D6%80%D5%A5%D5%BF%D5%A5&oldid=4737063>'])


add_sample('hy', '⡍⠁⠹⠁⠟⠁⠎⠛⠁⠗⠥ ⠍⠁⠱⠗⠮⠁⠍⠁⠅⠊⠮ ⠏⠁⠜⠁⠝⠧⠪⠺⠍ ⠑ ⡍⠪⠵⠁⠍⠏⠊⠛⠊ ⠇⠁⠱⠝ ⠝⠽⠣⠪⠺⠮⠪⠧⠄  ⢚⢑⢓⢊⠄',
           original='Մադագասկարը մայրցամաքից բաժանվում է Մոզամբիկի լայն նեղուցով։',
           english='Madagascar is separated from the continent by the wide strait of Mozambique.',
           script='Brai', flags=[], prio=PRIO_DEFAULT,
           sources=['Աֆրիկա - Վիքիպեդիա՝ ազատ հանրագիտարան, 21:53, 4 Մայիսի 2018  <https://hy.wikipedia.org/w/index.php?title=%D4%B1%D6%86%D6%80%D5%AB%D5%AF%D5%A1&oldid=5743237>'])


add_sample('hy', '⡟⠪⠗⠌⠁⠗⠛⠪⠺⠍⠊⠮ ⠓⠽⠙⠪ ⠁⠱⠝ ⠛⠹⠁⠻⠝⠁ ⠁⠍⠽⠝⠁⠍⠽⠌ ⠝⠁⠧⠝ ⠊⠗ ⠹⠁⠎⠊ ⠍⠽⠉⠄  ⢚⢑⢓⢊⠄',
           original='Գործարկումից հետո այն կդառնա ամենամեծ նավն իր դասի մեջ։',
           english='After its launch, it will be the largest ship in its class.',
           script='Brai', flags=[], prio=PRIO_DEFAULT,
           sources=['Նյու Յորք - Վիքիպեդիա՝ ազատ հանրագիտարան, 18:25, 30 Մարտի 2018 <https://hy.wikipedia.org/w/index.php?title=%D5%86%D5%B5%D5%B8%D6%82_%D5%85%D5%B8%D6%80%D6%84&oldid=5707433>'])


add_sample('ur-pk', '⠕⠝⠬ ⠍⠂ ⠁ ⠟⠱⠾ ⠵⠙⠓ ⠛⠁⠳⠰ ⠎ ⠛⠮⠗⠞⠌ ⠺⠟⠞ ⠁ ⠉⠻⠉⠻⠌⠂ ⠒⠌⠹⠗⠤⠋⠁⠗⠣ ⠩⠭⠯ ⠻ ⠃⠫ ⠚⠇ ⠏⠗⠊ ⠝⠍⠁ ⠁⠬⠙⠓⠌ ⠐⠝ ⠜⠄⠌⠲',
           original='ٹھنڈ میں، ایک قحط زدہ گاؤں سے گذرتے وقت ایک چڑچڑے، باأثر و فارغ شخص کو بعض جل پری نما اژدہے نظر آئے۔',
           english='In the cold, passing through an arid village, an irritable, influential and leisurely person saw some mermaid-like pythons.',
           script='Brai', flags=['grade2'], prio=PRIO_PREFER,
           sources=['List of Pangrams, Wikipedia, 12 October 2014 <https://web.archive.org/web/20141012231620/http://en.wikipedia.org/wiki/List_of_pangrams>'])


add_sample('chr-us', '⠁⠍⠑⠟⠕⠓⠊ ⠥⠝⠑⠎⠙⠁⠇⠁ ⠛⠑⠎⠧⠊ ⠛⠕⠗⠧⠓⠊ ⠊⠛⠕⠗⠧⠓⠊ ⠊⠛⠝⠑⠇⠧⠓⠊ ⠝⠊⠙⠧⠇⠑⠝⠧⠙⠁ ⠁⠍⠑⠟⠕⠓⠊ ⠁⠍⠁ ⠝⠁ ⠥⠝⠑⠎⠙⠁⠇⠁⠙⠧⠓⠊⠲',
           original='ᎠᎺᏉᎯ ᎤᏁᏍᏓᎳ ᎨᏒᎢ ᎪᏢᎯ ᎢᎪᏢᎯ ᎢgᏁᎸᎯ ᏂᏛᎴᏅᏓ ᎠᎺᏉᎯ ᎠᎹ Ꮎ ᎤᏁᏍᏓᎳᏛᎯ.',
           english=None,
           script='Brai', flags=['grade1'], prio=PRIO_WITHHOLD,
           sources=['ᎠᎺᏉᎯ ᎤᏁᏍᏓᎳ - Wikipedia, 02:23, 21 ᎠᎾᎠᎬᏘ 2018 <https://chr.wikipedia.org/w/index.php?title=%E1%8E%A0%E1%8E%BA%E1%8F%89%E1%8E%AF_%E1%8E%A4%E1%8F%81%E1%8F%8D%E1%8F%93%E1%8E%B3&oldid=42718>'])


add_sample('chr-us', '⠓⠁⠺⠊⠝⠁⠙⠊⠗⠧ ⠊⠽⠥⠎⠙⠊ ⠽⠁⠙⠧⠃⠁ ⠁⠇⠑ ⠁⠎⠥⠽⠑⠙⠊ ⠵⠥⠙⠁⠇⠑⠓⠧⠙⠁ ⠝⠧⠺⠕⠞⠊⠂ ⠁⠵⠁⠝⠧⠙⠕ ⠛⠑⠎⠧⠊ ⠊⠽⠁⠙⠧⠝⠑⠇⠊⠙⠁⠎⠙⠊⠲',
           original='ᎭᏫᎾᏗᏢ ᎢᏳᏍᏗ ᏯᏛᎿ ᎠᎴ ᎠᏑᏰᏗ ᏧᏓᎴᎲᏓ ᏅᏬᏘ, ᎠᏣᏅᏙ ᎨᏒᎢ ᎢᏯᏛᏁᎵᏓᏍᏗ.',
           english=None,
           script='Brai', flags=['grade1'], prio=PRIO_WITHHOLD,
           sources=['ᎠᏣᏅᏙ - Wikipedia, 12:41, 20 ᎧᏩᏂ 2018 <https://chr.wikipedia.org/w/index.php?title=%E1%8E%A0%E1%8F%A3%E1%8F%85%E1%8F%99&oldid=41857>'])


add_sample('chr-us', '⠙⠊⠎⠑⠎⠙⠊ ⠙⠁⠎⠙⠁⠝⠧⠝⠧ ⠙⠥⠇⠑⠝⠧ ⠵⠊⠝⠥⠎⠙⠊ ⠓⠊⠁ ⠗⠕⠛⠑⠎⠊ ⠧⠛⠁⠞⠁⠓⠧⠊ ⠁⠝⠊⠝⠁⠙⠑⠛⠧ ⠛⠧⠙⠕⠙⠊⠲',
           original='ᏗᏎᏍᏗ ᏓᏍᏓᏅᏅ ᏚᎴᏅ ᏥᏄᏍᏗ ᎯᎠ ᏠᎨᏏ ᎥᎦᏔᎲᎢ ᎠᏂᎾᏕᎬ ᎬᏙᏗ.',
           english=None,
           script='Brai', flags=['grade1'], prio=PRIO_WITHHOLD,
           sources=['ᏗᏎᏍᏗ ᏓᏍᏓᏅᏅ - Wikipedia, 12:50, 20 ᎧᏩᏂ 2018 <https://chr.wikipedia.org/w/index.php?title=%E1%8F%97%E1%8F%8E%E1%8F%8D%E1%8F%97_%E1%8F%93%E1%8F%8D%E1%8F%93%E1%8F%85%E1%8F%85&oldid=42422>'])


add_sample('mn-mn', '⡈⠌⢭⠂⠦⠆⢁⡈⡈⠌⢭⠂⠦⠆⠆⡈ ⡈⠌⢭⠂⠦⠒⠴⡈⡈⠌⢭⠂⠦⠆⠆⡈⡈⠌⢭⠂⠦⠆⢋⡈⡈⠌⢭⠂⠦⠆⠆⡈ ⡈⠌⢭⠂⠦⠆⠆⡈⡈⠌⢭⠂⠦⠒⠒⡈⡈⠌⢭⠂⠦⠆⠂⡈⡈⠌⢭⠂⠦⠒⠖⡈⡈⠌⢭⠂⠦⠆⠖⡈ ⡈⠌⢭⠂⠦⠒⠲⡈⡈⠌⢭⠂⠦⠆⠆⡈⡈⠌⢭⠂⠦⠒⠒⡈⡈⠌⢭⠂⠦⠆⠴⡈⡈⠌⢭⠂⠦⠆⠦⡈⡈⠌⢭⠂⠦⠆⠴⡈ ⡈⠌⢭⠂⠦⠴⠆⡈ ⡈⠌⢭⠂⠦⠆⠦⡈⡈⠌⢭⠂⠦⠆⠴⡈⡈⠌⢭⠂⠦⠒⠒⡈⡈⠌⢭⠂⠦⠆⠲⡈⡈⠌⢭⠂⠦⠒⠶⡈ ⡈⠌⢭⠂⠦⠆⢉⡈⡈⠌⢭⠂⠦⠆⠒⡈⡈⠌⢭⠂⠦⠆⠲⡈⡈⠌⢭⠂⠦⠒⠶⡈⡈⠌⢭⠂⠦⠆⠴⡈⡈⠌⢭⠂⠦⠒⠒⡈⡈⠌⢭⠂⠦⠆⠴⡈⡈⠌⢭⠂⠦⠆⠆⡈ ⡈⠌⢭⠂⠦⠆⢁⡈⡈⠌⢭⠂⠦⠆⠆⡈⡈⠌⢭⠂⠦⠒⠴⡈⡈⠌⢭⠂⠦⠆⠆⡈',
           original='ᠪᠢ ᠰᠢᠯᠢ ᠢᠳᠡᠶᠦ ᠴᠢᠳᠠᠨᠠ ᠂ ᠨᠠᠳᠤᠷ ᠬᠣᠤᠷᠠᠳᠠᠢ ᠪᠢᠰᠢ',
           english="I can eat glass and it doesn't hurt me.",
           script='Brai', flags=['grade2'], prio=PRIO_PREFER,
           sources=['Pango Language Sample Table', 'UTF-8 Sampler - The Kermit Project <http://kermitproject.org/utf8.html>'])


add_sample('mn-mn', '⠠⠭⠘⠒⠑⠞⠅⠁⠝⠮ ⠋⠑⠗⠍⠙ ⠏⠊⠯⠱⠊⠝ ⠉⠥⠺⠷⠫⠲ ⠠⠃⠧⠛⠚ ⠵⠕⠛⠎⠟ ⠓⠪⠇⠾⠳⠹⠲',
           original='Щётканы фермд пийшин цувъя. Бөгж зогсч хэльюү.',
           english="Let's echelon fireplaces in brush farm. Ring says standing.",
           script='Brai', flags=['grade2'], prio=PRIO_PREFER,
           sources=['List of Pangrams, Wikipedia, 12 October 2014 <https://web.archive.org/web/20141012231620/http://en.wikipedia.org/wiki/List_of_pangrams>'])


add_sample('mn-mn', '⠠⠓⠹⠯⠞⠪⠝ ⠁⠛⠁⠁⠗ ⠙⠥⠇⠁⠁⠝ ⠁⠛⠁⠁⠗ ⠇⠥⠥ ⠱⠊⠇⠚⠊⠚ ⠃⠥⠯ ⠹⠑⠙ ⠹⠹⠎⠝⠪⠲',
           original='Хүйтэн агаар дулаан агаар луу шилжиж буй үед үүснэ.',
           english='Cold air appears when the warm air is updrafted',
           script='Brai', flags=['grade2'], prio=PRIO_PREFER,
           sources=['Агаарын фронт — Википедиа нэвтэрхий толь, 17:40, 11 Наймдугаар сар 2014-ий <https://mn.wikipedia.org/w/index.php?title=%D0%90%D0%B3%D0%B0%D0%B0%D1%80%D1%8B%D0%BD_%D1%84%D1%80%D0%BE%D0%BD%D1%82&oldid=401772>'])


add_sample('mn-mn', '⠠⠪⠝⠪ ⠹⠑⠙ ⠵⠁⠗⠊⠍⠙⠁⠁ ⠧⠝⠙⠗⠊⠯⠝ ⠃⠧⠧⠝ ⠹⠹⠇ ⠹⠹⠎⠝⠪⠲',
           original='Энэ үед заримдаа өндрийн бөөн үүл үүснэ.',
           english='During that time, sometimes high-altitude clouds appear',
           script='Brai', flags=['grade2'], prio=PRIO_PREFER,
           sources=['Агаарын фронт — Википедиа нэвтэрхий толь, 17:40, 11 Наймдугаар сар 2014-ий <https://mn.wikipedia.org/w/index.php?title=%D0%90%D0%B3%D0%B0%D0%B0%D1%80%D1%8B%D0%BD_%D1%84%D1%80%D0%BE%D0%BD%D1%82&oldid=401772>'])


add_sample('mn-mn', '⠠⠝⠫⠛⠞⠗⠁⠇ ⠛⠪⠙⠪⠛ ⠝⠾ ⠏⠊⠅⠎⠑⠇⠪⠪⠗ ⠊⠇⠪⠗⠓⠊⠯⠇⠎⠪⠝ ⠓⠧⠝⠙⠇⠧⠝ ⠃⠁ ⠃⠕⠎⠕⠕ ⠓⠪⠍⠚⠪⠪ ⠳⠍⠲',
           original='Нягтрал гэдэг нь пикселээр илэрхийлсэн хөндлөн ба босоо хэмжээ юм.',
           english='Resolution is two-dimensional quantity expressed in vertical and horizontal amount of pixels',
           script='Brai', flags=['grade2'], prio=PRIO_PREFER,
           sources=['Шингэн кристалан дэлгэц — Википедиа нэвтэрхий толь, 10:25, 18 Наймдугаар сар 2015-ий <https://mn.wikipedia.org/w/index.php?title=%D0%A8%D0%B8%D0%BD%D0%B3%D1%8D%D0%BD_%D0%BA%D1%80%D0%B8%D1%81%D1%82%D0%B0%D0%BB%D0%B0%D0%BD_%D0%B4%D1%8D%D0%BB%D0%B3%D1%8D%D1%86&oldid=442940>'])


add_sample('bo', '⠄⢡⢭⠴⢋⠴⠦⠄ ⠙⠅⠗⠄⢡⢭⠴⢋⠴⢃⠄⠍⠿⠄⢡⢭⠴⢋⠶⢁⠄⠮⠄⢡⢭⠴⢋⠴⢃⠄⠁⠄⢡⢭⠴⢋⠴⢃⠄⠚⠄⢡⢭⠴⢋⠶⠆⠄⠛⠄⢡⢭⠴⢋⠴⢃⠄⠇⠮⠄⢡⢭⠴⢋⠴⢃⠄⠫⠉⠗⠄⢡⢭⠴⢋⠶⠲⠄⠶⠮⠄⢡⢭⠴⢋⠴⢃⠄⠚⠄⢡⢭⠴⢋⠶⢁⠄⠄⢡⢭⠴⢋⠴⢃⠄⠱⠄⢡⢭⠴⢋⠶⢁⠄⠮⠄⢡⢭⠴⢋⠴⢃⠄⠛⠞⠄⢡⢭⠴⢋⠶⢁⠄⠗⠄⢡⢭⠴⢋⠴⢙⠄ ⠄⢡⢭⠴⢋⠴⢙⠄⠯⠮⠄⢡⢭⠴⢋⠴⢃⠄⠗⠛⠄⢡⢭⠴⢋⠶⢉⠄⠇⠄⢡⢭⠴⢋⠴⢃⠄⠺⠄⢡⢭⠴⢋⠴⢃⠄⠮⠅⠚⠄⢡⢭⠴⢋⠶⢁⠄⠮⠄⢡⢭⠴⢋⠴⢃⠄⠎⠄⢡⢭⠴⢋⠶⠆⠄⠇⠄⢡⢭⠴⢋⠴⢃⠄⠛⠝⠄⢡⢭⠴⢋⠶⢉⠄⠝⠄⢡⢭⠴⢋⠴⢃⠄⠛⠙⠄⢡⢭⠴⢋⠶⢉⠄⠶⠄⢡⢭⠴⢋⠴⢃⠄⠇⠶⠄⢡⢭⠴⢋⠴⢃⠄⠃⠩⠄⢡⢭⠴⢋⠶⠆⠄⠝⠄⢡⢭⠴⢋⠴⢙⠄ ⠄⢡⢭⠴⢋⠴⢙⠄⠽⠛⠮⠄⢡⢭⠴⢋⠴⢃⠄⠾⠄⢡⢭⠴⢋⠶⢉⠄⠛⠮⠄⢡⢭⠴⢋⠴⢃⠄⠅⠄⢡⢭⠴⢋⠶⠲⠄⠝⠄⢡⢭⠴⢋⠴⢃⠄⠃⠗⠇⠄⢡⢭⠴⢋⠴⢃⠄⠍⠵⠄⢡⢭⠴⢋⠶⠲⠄⠶⠮⠄⢡⢭⠴⢋⠴⢃⠄⠍⠄⢡⢭⠴⢋⠶⢁⠄⠙⠄⢡⢭⠴⢋⠴⢃⠄⠫⠟⠍⠄⢡⢭⠴⢋⠴⢃⠄⠃⠚⠶⠮⠄⢡⢭⠴⢋⠴⢃⠄⠍⠾⠄⢡⢭⠴⢋⠶⠲⠄⠮⠄⢡⢭⠴⢋⠴⢙⠄ ⠄⢡⢭⠴⢋⠴⢙⠄⠍⠄⢡⢭⠴⢋⠴⢃⠄⠓⠄⢡⢭⠴⢋⠶⠂⠄⠄⢡⢭⠴⢋⠴⢃⠄⠍⠉⠮⠄⢡⢭⠴⢋⠴⢃⠄⠏⠫⠄⢡⢭⠴⢋⠶⠆⠄⠄⢡⢭⠴⢋⠴⢃⠄⠛⠭⠄⢡⢭⠴⢋⠶⢉⠄⠄⢡⢭⠴⢋⠴⢃⠄⠃⠄⢡⢭⠴⢋⠶⢉⠄⠄⢡⢭⠴⢋⠴⢃⠄⠜⠄⢡⢭⠴⢋⠶⠆⠄⠙⠄⢡⢭⠴⢋⠴⢃⠄⠛⠚⠄⢡⢭⠴⢋⠶⠲⠄⠗⠄⢡⢭⠴⢋⠴⢃⠄⠹⠄⢡⢭⠴⢋⠶⠆⠄⠛⠄⢡⢭⠴⢋⠴⢙⠄',
           original='༈ དཀར་མཛེས་ཨ་ཡིག་ལས་འཁྲུངས་ཡེ་ཤེས་གཏེར། །ཕས་རྒོལ་ཝ་སྐྱེས་ཟིལ་གནོན་གདོང་ལྔ་བཞིན། །ཆགས་ཐོགས་ཀུན་བྲལ་མཚུངས་མེད་འཇམ་བྱངས་མཐུས། །མ་ཧཱ་མཁས་པའི་གཙོ་བོ་ཉིད་གྱུར་ཅིག།',
           english=None,
           script='Brai', flags=[], prio=PRIO_DEFAULT,
           sources=['List of Pangrams, Wikipedia, 12 October 2014 <https://web.archive.org/web/20141012231620/http://en.wikipedia.org/wiki/List_of_pangrams>'])


add_sample('bo', '⠵⠄⢡⢭⠴⢋⠴⢃⠄⠃⠄⢡⢭⠴⢋⠴⢃⠄⠗⠄⢡⢭⠴⢋⠶⠆⠄⠛⠄⢡⢭⠴⢋⠴⢃⠄⠏⠄⢡⢭⠴⢋⠴⢃⠄⠝⠄⢡⢭⠴⢋⠶⠆⠄⠄⢡⢭⠴⢋⠴⢃⠄⠵⠄⢡⢭⠴⢋⠴⢃⠄⠃⠫⠄⢡⢭⠴⢋⠶⠆⠄⠄⢡⢭⠴⢋⠴⢃⠄⠃⠚⠄⢡⢭⠴⢋⠶⠲⠄⠶⠄⢡⢭⠴⢋⠴⢃⠄⠃⠄⢡⢭⠴⢋⠴⢃⠄⠙⠶⠄⢡⢭⠴⢋⠴⢃⠄⠃⠗⠛⠚⠄⢡⢭⠴⢋⠶⠲⠄⠙⠄⢡⢭⠴⢋⠴⢃⠄⠮⠏⠗⠄⢡⢭⠴⢋⠶⢉⠄⠙⠄⢡⢭⠴⢋⠴⢃⠄⠇⠄⢡⢭⠴⢋⠴⢃⠄⠩⠄⢡⢭⠴⢋⠶⠆⠄⠃⠄⢡⢭⠴⢋⠴⢃⠄⠫⠟⠄⢡⢭⠴⢋⠶⠲⠄⠛⠄⢡⢭⠴⢋⠴⢃⠄⠙⠶⠄⢡⢭⠴⢋⠴⢃⠄⠄⢡⢭⠴⢋⠴⢙⠄ ⠵⠄⢡⢭⠴⢋⠴⢃⠄⠃⠫⠄⢡⢭⠴⢋⠶⠆⠄⠄⢡⢭⠴⢋⠴⢃⠄⠗⠝⠍⠄⢡⢭⠴⢋⠴⢃⠄⠏⠫⠄⢡⢭⠴⢋⠶⠆⠄⠄⢡⢭⠴⢋⠴⢃⠄⠫⠄⢡⢭⠴⢋⠶⢉⠄⠛⠄⢡⢭⠴⢋⠴⢃⠄⠛⠄⢡⢭⠴⢋⠶⠆⠄⠄⢡⢭⠴⢋⠴⢃⠄⠙⠶⠄⢡⢭⠴⢋⠶⢉⠄⠮⠄⢡⢭⠴⢋⠴⢃⠄⠏⠄⢡⢭⠴⢋⠶⢉⠄⠫⠄⢡⢭⠴⢋⠶⠆⠄⠄⢡⢭⠴⢋⠴⢃⠄⠗⠶⠄⢡⢭⠴⢋⠴⢃⠄⠃⠩⠄⢡⢭⠴⢋⠶⠆⠄⠝⠄⢡⢭⠴⢋⠴⢃⠄⠙⠶⠄⢡⢭⠴⢋⠴⢃⠄⠙⠄⢡⢭⠴⢋⠶⢁⠄⠫⠄⢡⢭⠴⢋⠶⠆⠄⠄⢡⢭⠴⢋⠴⢃⠄⠫⠛⠚⠄⢡⢭⠴⢋⠶⠲⠄⠗⠄⢡⢭⠴⢋⠴⢃⠄⠇⠙⠄⢡⢭⠴⢋⠶⢉⠄⠛⠄⢡⢭⠴⢋⠴⢃⠄⠇⠄⢡⢭⠴⢋⠴⢃⠄⠩⠄⢡⢭⠴⢋⠶⠆⠄⠃⠄⢡⢭⠴⢋⠴⢃⠄⠫⠟⠄⢡⢭⠴⢋⠶⠲⠄⠛⠄⢡⢭⠴⢋⠴⢃⠄⠃⠚⠄⢡⢭⠴⢋⠶⢁⠄⠙⠄⢡⢭⠴⢋⠴⢃⠄⠏⠫⠄⢡⢭⠴⢋⠶⠆⠄⠄⢡⢭⠴⢋⠴⢃⠄⠗⠄⢡⢭⠴⢋⠶⠆⠄⠛⠄⢡⢭⠴⢋⠴⢃⠄⠵⠝⠄⢡⢭⠴⢋⠴⢃⠄⠩⠄⢡⢭⠴⢋⠶⠆⠄⠛⠄⢡⢭⠴⢋⠴⢃⠄⠚⠄⢡⢭⠴⢋⠶⠆⠄⠝⠄⢡⢭⠴⢋⠴⢙⠄',
           original='ཚ་བ་རིག་པ་ནི་ཚ་བའི་བྱུང་བ་དང་བརྒྱུད་སྤྲོད་ལ་ཞིབ་འཇུག་དང་། ཚ་བའི་རྣམ་པའི་འོག་གི་དངོས་པོའི་རང་བཞིན་དང་དེའི་འགྱུར་ལྡོག་ལ་ཞིབ་འཇུག་བྱེད་པའི་རིག་ཚན་ཞིག་ཡིན།',
           english=None,
           script='Brai', flags=[], prio=PRIO_DEFAULT,
           sources=['ཚ་བ་རིག་པ་ - Wikipedia, ༡༧:༤༦, ༢༤ ཟླ་བཅུ་གཅིག་པ། ༢༠༡༣ <https://bo.wikipedia.org/w/index.php?title=%E0%BD%9A%E0%BC%8B%E0%BD%96%E0%BC%8B%E0%BD%A2%E0%BD%B2%E0%BD%82%E0%BC%8B%E0%BD%94%E0%BC%8B&oldid=126203>'])


add_sample('ga', '⠄⡳⠭⠴⠂⠴⠁⠄⠥⠁⠊⠄⡳⠭⠴⠂⠆⠂⠄ ⠃⠿ ⠄⡳⠭⠂⠑⠲⠂⠄⠮⠗⠄⡳⠭⠂⠑⠖⠂⠄⠯⠄⡳⠭⠴⠂⠴⠃⠄ ⠇⠑ ⠙⠇⠾⠄⡳⠭⠂⠑⠖⠃⠄⠎⠏⠯⠙ ⠋⠷⠕⠗⠄⡳⠭⠂⠑⠂⠋⠄⠔⠝ ⠞⠗⠷ ⠓⠁⠞⠁ ⠍⠕ ⠄⡳⠭⠂⠑⠴⠃⠄⠑⠁⠤⠄⡳⠭⠂⠑⠢⠶⠄⠕⠗⠉⠯⠔ ⠄⡳⠭⠂⠑⠴⠒⠄⠊⠛⠲',
           original='Ċuaiġ bé ṁórṡáċ le dlúṫspád fíorḟinn trí hata mo ḋea-ṗorcáin ḃig.',
           english='A greatly satisfied woman went with a truly white dense spade through the hat of my good little well-fattened pig',
           script='Brai', flags=['grade2'], prio=PRIO_PREFER,
           sources=['Pango Language Sample Table', 'List of Pangrams, Wikipedia, 12 October 2014 <https://web.archive.org/web/20141012231620/http://en.wikipedia.org/wiki/List_of_pangrams>'])


add_sample('gd', '⡍⠥⠎ ⠙⠄⠋⠓⠄ ⠭⢚⢚⠑⢚⠄⠛ ⡉⠄ ⠭⢚⢚⠑⢓⠄⠊⠞⠤⠄ ⠭⢚⢚⠙⢊⠄⠝⠁ ⠗⠄ ⠭⢚⢚⠋⢃⠄⠏ ⠄ ⠭⢚⢚⠉⠉⠄ ⠇⠑ ⠕⠃⠲',
           original="Mus d'fhàg Cèit-Ùna ròp Ì le ob.",
           english='Before Kate-Una left the Iona cattle auction with hops.',
           script='Brai', flags=[], prio=PRIO_DEFAULT,
           sources=['List of Pangrams, Wikipedia, 12 October 2014 <https://web.archive.org/web/20141012231620/http://en.wikipedia.org/wiki/List_of_pangrams>'])


add_sample('zh-chn', '⠱⠆⠑⠥⠓⠩⠛⠶⠐ ⠟⠶⠽⠳⠇⠧⠞⠩',
           original='視野無限廣，窗外有藍天',
           english='The view is infinitely wide. There is blue sky outside the window.',
           script='Brai', flags=[], prio=PRIO_DEFAULT,
           sources=['List of Pangrams, Wikipedia, 12 October 2014 <https://web.archive.org/web/20141012231620/http://en.wikipedia.org/wiki/List_of_pangrams>'])


add_sample('zh-hk', '⠎⠊⠂⠚⠑⠠⠍⠧⠄⠓⠘⠂⠟⠰⠁⠤⠭⠒⠛⠣⠂⠚⠡⠠⠇⠜⠄⠾⠲',
           original='視野無限廣，窗外有藍天',
           english='The view is infinitely wide. There is blue sky outside the window.',
           script='Brai', flags=[], prio=PRIO_DEFAULT,
           sources=['List of Pangrams, Wikipedia, 12 October 2014 <https://web.archive.org/web/20141012231620/http://en.wikipedia.org/wiki/List_of_pangrams>'])


add_sample('zh-tw', '⠊⠱⠐⠬⠈⠌⠂⠑⠞⠐⠅⠸⠈⠆ ⠃⠸⠄⠶⠐⠎⠈⠉⠧⠂⠋⠞⠄',
           original='視野無限廣，窗外有藍天',
           english='The view is infinitely wide. There is blue sky outside the window.',
           script='Brai', flags=[], prio=PRIO_DEFAULT,
           sources=['List of Pangrams, Wikipedia, 12 October 2014 <https://web.archive.org/web/20141012231620/http://en.wikipedia.org/wiki/List_of_pangrams>'])


add_sample('zh-chn', '⠺⠋⠼⠡⠅⠢⠐ ⠚⠻⠬⠃⠧⠟⠔',
           original='微風迎客，軟語伴茶',
           english='The breeze sees the guest in. Soft voice accompanies the tea.',
           script='Brai', flags=[], prio=PRIO_DEFAULT,
           sources=['List of Pangrams, Wikipedia, 12 October 2014 <https://web.archive.org/web/20141012231620/http://en.wikipedia.org/wiki/List_of_pangrams>'])


add_sample('zh-hk', '⠍⠓⠄⠋⠦⠚⠴⠄⠓⠅⠐⠤⠆⠠⠹⠠⠏⠮⠂⠭⠃⠄',
           original='微風迎客，軟語伴茶',
           english='The breeze sees the guest in. Soft voice accompanies the tea.',
           script='Brai', flags=[], prio=PRIO_DEFAULT,
           sources=['List of Pangrams, Wikipedia, 12 October 2014 <https://web.archive.org/web/20141012231620/http://en.wikipedia.org/wiki/List_of_pangrams>'])


add_sample('zh-tw', '⠫⠂⠟⠵⠄⠽⠂⠇⠮⠐⠆ ⠛⠻⠈⠳⠈⠕⠧⠐⠃⠜⠂',
           original='微風迎客，軟語伴茶',
           english='The breeze sees the guest in. Soft voice accompanies the tea.',
           script='Brai', flags=[], prio=PRIO_DEFAULT,
           sources=['List of Pangrams, Wikipedia, 12 October 2014 <https://web.archive.org/web/20141012231620/http://en.wikipedia.org/wiki/List_of_pangrams>'])


add_sample('zh-chn', '⠕⠝⠼⠞⠒⠓⠫⠃⠢⠇⠊⠗⠃⠥⠱⠦⠱⠴⠞⠊⠐⠆',
           original='我能吞下玻璃而不伤身体。',
           english="I can eat glass and it doesn't hurt me.",
           script='Brai', flags=[], prio=PRIO_DEFAULT,
           sources=['Pango Language Sample Table', 'UTF-8 Sampler - The Kermit Project <http://kermitproject.org/utf8.html>'])


add_sample('zh-hk', '⠛⠕⠠⠝⠛⠄⠾⠫⠓⠃⠂⠏⠕⠇⠓⠄⠊⠄⠏⠔⠄⡳⠭⠲⠋⠆⠲⠄⠎⠫⠾⠩⠁⠿ ',
           original='我能吞下玻璃而不伤身体。',
           english="I can eat glass and it doesn't hurt me.",
           script='Brai', flags=[], prio=PRIO_DEFAULT,
           sources=['Pango Language Sample Table', 'UTF-8 Sampler - The Kermit Project <http://kermitproject.org/utf8.html>'])


add_sample('zh-tw', '⠒⠈⠝⠵⠂⠋⠿⠄⠑⠾⠐⠕⠣⠄⠉⠡⠂⠱⠂⠕⠌⠐⠊⠭⠄⠊⠥⠄⠋⠡⠈⠤ ',
           original='我能吞下玻璃而不伤身体。',
           english="I can eat glass and it doesn't hurt me.",
           script='Brai', flags=[], prio=PRIO_DEFAULT,
           sources=['Pango Language Sample Table', 'UTF-8 Sampler - The Kermit Project <http://kermitproject.org/utf8.html>'])


add_sample('cy-cy', '⠠⠙⠺ ⠊⠄⠰⠝ ⠛⠁⠇⠇⠥ ⠃⠺⠽⠞⠁ ⠛⠺⠽⠙⠗⠂ ⠠⠦⠙⠽⠺ ⠰⠑ ⠙⠙⠊⠍ ⠽⠝ ⠛⠝⠙ ⠙⠕⠇⠥⠗ ⠊ ⠍⠊⠲',
           original="Dw i'n gallu bwyta gwydr, 'dyw e ddim yn gwneud dolur i mi.",
           english="I can eat glass and it doesn't hurt me.",
           script='Brai', flags=['grade2'], prio=PRIO_PREFER,
           sources=['Pango Language Sample Table', 'UTF-8 Sampler - The Kermit Project <http://kermitproject.org/utf8.html>'])


add_sample('cy-cy', '⠠⠋⠽⠙⠙⠁⠝ ⠝⠓⠺⠄⠰⠝ ⠉⠽⠎⠛⠥ ⠙⠙⠊⠍ ⠕⠝⠙ ⠏⠁⠝ ⠋⠽⠙⠙ ⠁⠝⠛⠢⠲',
           original="Fyddan nhw'n cysgu ddim ond pan fydd angen.",
           english="They'll sleep only when there's a need.",
           script='Brai', flags=['grade2'], prio=PRIO_PREFER,
           sources=['Welsh language - Wikipedia, 10:40, 3 June 2018 <https://en.wikipedia.org/w/index.php?title=Welsh_language&oldid=844206066>'])


add_sample('cy-cy', '⠠⠙⠕⠑⠙⠙ ⠕ ⠙⠙⠊⠍ ⠺ ⠎⠑⠋⠽⠇⠇ ⠽⠝⠕⠄⠰⠝ ⠓⠊⠗⠲',
           original="Doedd o ddim wedi sefyll yno'n hir.",
           english='He had not stood there long.',
           script='Brai', flags=['grade2'], prio=PRIO_PREFER,
           sources=['Welsh language - Wikipedia, 10:40, 3 June 2018 <https://en.wikipedia.org/w/index.php?title=Welsh_language&oldid=844206066>'])


add_sample('cy-cy', '⠠⠗⠺⠽⠄⠰⠝ ⠉⠕⠙⠊⠄⠰⠝ ⠛⠽⠝⠝⠜ ⠃⠕⠃ ⠐⠙⠲',
           original="Rwy'n codi'n gynnar bob dydd.",
           english='I get up early every day.',
           script='Brai', flags=['grade2'], prio=PRIO_PREFER,
           sources=['Welsh language - Wikipedia, 10:40, 3 June 2018 <https://en.wikipedia.org/w/index.php?title=Welsh_language&oldid=844206066>'])


add_sample('ta-ta', '⠰⠅⠈⠇⠧⠊⠰⠽⠑ ⠥⠇⠰⠅⠌ ⠰⠍⠜⠈⠻⠻⠰⠈⠅⠰⠅⠳⠰⠾⠊⠰⠽ ⠉⠈⠅⠰⠞⠊ ⠰⠍⠊⠰⠈⠅⠰⠅ ⠜⠰⠽⠥⠞⠈⠍⠲',
           original='கல்வியே உலகை மாற்றக்கூடிய சக்தி மிக்க ஆயுதம்.',
           english='Education is the most powerful weapon we can use to change the world.',
           script='Brai', flags=['grade1'], prio=PRIO_WITHHOLD,
           sources=['Nelson Mandela - Wikiquote, 06:45, 30 April 2018 <https://en.wikiquote.org/w/index.php?title=Nelson_Mandela&oldid=2398814>', 'நெல்சன் மண்டேலா - விக்கிமேற்கோள், 06:44, 8 பெப்ரவரி 2018 <https://ta.wikiquote.org/w/index.php?title=%E0%AE%A8%E0%AF%86%E0%AE%B2%E0%AF%8D%E0%AE%9A%E0%AE%A9%E0%AF%8D_%E0%AE%AE%E0%AE%A3%E0%AF%8D%E0%AE%9F%E0%AF%87%E0%AE%B2%E0%AE%BE&oldid=15046>'])


add_sample('ta', '⠅⠇⠈⠧⠊⠽⠑ ⠥⠇⠅⠌ ⠍⠜⡗⠈⡗⠅⠈⠅⠳⠾⠊⠽ ⠉⠅⠈⠞⠊ ⠍⠊⠅⠈⠅ ⠜⠽⠥⠞⠍⠈⠄⠨⠄',
           original='கல்வியே உலகை மாற்றக்கூடிய சக்தி மிக்க ஆயுதம்.',
           english='Education is the most powerful weapon we can use to change the world.',
           script='Brai', flags=[], prio=PRIO_DEFAULT,
           sources=['Nelson Mandela - Wikiquote, 06:45, 30 April 2018 <https://en.wikiquote.org/w/index.php?title=Nelson_Mandela&oldid=2398814>', 'நெல்சன் மண்டேலா - விக்கிமேற்கோள், 06:44, 8 பெப்ரவரி 2018 <https://ta.wikiquote.org/w/index.php?title=%E0%AE%A8%E0%AF%86%E0%AE%B2%E0%AF%8D%E0%AE%9A%E0%AE%A9%E0%AF%8D_%E0%AE%AE%E0%AE%A3%E0%AF%8D%E0%AE%9F%E0%AF%87%E0%AE%B2%E0%AE%BE&oldid=15046>'])


add_sample('ta-ta', '⠰⠉⠢⠰⠈⠽⠰⠞⠥ ⠰⠍⠥⠰⠾⠊⠰⠈⠅⠰⠅⠥⠰⠈⠍ ⠧⠰⠗⠌ ⠰⠉⠢⠰⠈⠽⠰⠽ ⠰⠍⠥⠰⠾⠊⠰⠽⠜⠞⠞⠥ ⠰⠏⠕⠇⠰⠈⠞⠰⠞⠜⠰⠈⠰ ⠊⠰⠗⠥⠰⠈⠅⠰⠅⠥⠰⠈⠍⠲',
           original='செய்து முடிக்கும் வரை செய்ய முடியாதது போலத்தான் இருக்கும்.',
           english='It always seems impossible until it is done.',
           script='Brai', flags=['grade1'], prio=PRIO_WITHHOLD,
           sources=['Nelson Mandela - Wikiquote, 06:45, 30 April 2018 <https://en.wikiquote.org/w/index.php?title=Nelson_Mandela&oldid=2398814>', 'நெல்சன் மண்டேலா - விக்கிமேற்கோள், 06:44, 8 பெப்ரவரி 2018 <https://ta.wikiquote.org/w/index.php?title=%E0%AE%A8%E0%AF%86%E0%AE%B2%E0%AF%8D%E0%AE%9A%E0%AE%A9%E0%AF%8D_%E0%AE%AE%E0%AE%A3%E0%AF%8D%E0%AE%9F%E0%AF%87%E0%AE%B2%E0%AE%BE&oldid=15046>'])


add_sample('ta', '⠉⡌⠽⠈⠞⠥ ⠍⠥⠾⠊⠅⠈⠅⠥⠍⠈ ⠧⠗⠌ ⠉⡌⠽⠈⠽ ⠍⠥⠾⠊⠽⠜⠞⠞⠥ ⠏⠕⠇⠞⠈⠞⠜⠰⠈ ⠊⠗⠥⠅⠈⠅⠥⠍⠈⠄⠨⠄',
           original='செய்து முடிக்கும் வரை செய்ய முடியாதது போலத்தான் இருக்கும்.',
           english='It always seems impossible until it is done.',
           script='Brai', flags=[], prio=PRIO_DEFAULT,
           sources=['Nelson Mandela - Wikiquote, 06:45, 30 April 2018 <https://en.wikiquote.org/w/index.php?title=Nelson_Mandela&oldid=2398814>', 'நெல்சன் மண்டேலா - விக்கிமேற்கோள், 06:44, 8 பெப்ரவரி 2018 <https://ta.wikiquote.org/w/index.php?title=%E0%AE%A8%E0%AF%86%E0%AE%B2%E0%AF%8D%E0%AE%9A%E0%AE%A9%E0%AF%8D_%E0%AE%AE%E0%AE%A3%E0%AF%8D%E0%AE%9F%E0%AF%87%E0%AE%B2%E0%AE%BE&oldid=15046>'])


add_sample('ta-ta', '⠰⠝⠈⠇⠇ ⠰⠞⠇⠌⠰⠽⠥⠰⠈⠍ ⠰⠝⠈⠇⠇ ⠊⠞⠽⠍⠥⠰⠈⠍ ⠢⠰⠈⠏⠰⠏⠭⠷⠥⠰⠞⠥⠰⠈⠍ ⠧⠈⠇⠇⠰⠍⠌ ⠰⠍⠊⠰⠈⠅⠰⠅ ⠰⠉⠑⠰⠈⠗⠰⠈⠅⠰⠅⠌⠰⠽⠜⠰⠅⠥⠰⠈⠍⠲',
           original='நல்ல தலையும் நல்ல இதயமும் எப்பொழுதும் வல்லமை மிக்க சேர்க்கையாகும்.',
           english='A good head and a good heart are always a formidable combination.',
           script='Brai', flags=['grade1'], prio=PRIO_WITHHOLD,
           sources=['Nelson Mandela - Wikiquote, 06:45, 30 April 2018 <https://en.wikiquote.org/w/index.php?title=Nelson_Mandela&oldid=2398814>', 'நெல்சன் மண்டேலா - விக்கிமேற்கோள், 06:44, 8 பெப்ரவரி 2018 <https://ta.wikiquote.org/w/index.php?title=%E0%AE%A8%E0%AF%86%E0%AE%B2%E0%AF%8D%E0%AE%9A%E0%AE%A9%E0%AF%8D_%E0%AE%AE%E0%AE%A3%E0%AF%8D%E0%AE%9F%E0%AF%87%E0%AE%B2%E0%AE%BE&oldid=15046>'])


add_sample('ta', '⠝⠇⠈⠇ ⠞⠇⠌⠽⠥⠍⠈ ⠝⠇⠈⠇ ⠊⠞⠽⠍⠥⠍⠈ ⡌⠏⠈⠏⡪⣇⠥⠞⠥⠍⠈ ⠧⠇⠈⠇⠍⠌ ⠍⠊⠅⠈⠅ ⠉⠑⠗⠈⠅⠈⠅⠌⠽⠜⠅⠥⠍⠈⠄⠨⠄',
           original='நல்ல தலையும் நல்ல இதயமும் எப்பொழுதும் வல்லமை மிக்க சேர்க்கையாகும்.',
           english='A good head and a good heart are always a formidable combination.',
           script='Brai', flags=[], prio=PRIO_DEFAULT,
           sources=['Nelson Mandela - Wikiquote, 06:45, 30 April 2018 <https://en.wikiquote.org/w/index.php?title=Nelson_Mandela&oldid=2398814>', 'நெல்சன் மண்டேலா - விக்கிமேற்கோள், 06:44, 8 பெப்ரவரி 2018 <https://ta.wikiquote.org/w/index.php?title=%E0%AE%A8%E0%AF%86%E0%AE%B2%E0%AF%8D%E0%AE%9A%E0%AE%A9%E0%AF%8D_%E0%AE%AE%E0%AE%A3%E0%AF%8D%E0%AE%9F%E0%AF%87%E0%AE%B2%E0%AE%BE&oldid=15046>'])


add_sample('mt', '⡋⠄ ⠭⢃⢚⢁⢊⠄⠙⠁⠵⠤⠵⠍⠊⠑⠝ ⠅⠊⠞⠑⠃ ⠱⠁⠋⠝⠁ ⠧⠑⠗⠎⠊ ⠥ ⠃⠊⠡⠡⠊⠑⠞ ⠟⠕⠎⠗⠁⠲',
           original='F’daż-żmien kiteb ħafna versi u biċċiet qosra.',
           english='He devoted his spare time to writing novels and short stories.',
           script='Brai', flags=[], prio=PRIO_DEFAULT,
           sources=['Guy de Maupassant - Wikipedija, 22:48, 15 Mejju 2015 <https://mt.wikipedia.org/w/index.php?title=Guy_de_Maupassant&oldid=243806>', 'Guy de Maupassant - Wikipedia, 15:16, 28 May 2018 <https://en.wikipedia.org/w/index.php?title=Guy_de_Maupassant&oldid=843347873>'])


add_sample('mt', '⡃⠊⠞⠤⠞⠁⠇⠑⠝⠞ ⠥ ⠎⠤⠎⠑⠝⠎ ⠅⠥⠍⠍⠑⠗⠡⠽⠁⠇⠊ ⠇⠊ ⠅⠑⠇⠇⠥ ⠍⠁ ⠙⠁⠍⠭ ⠍⠁ ⠎⠁⠗ ⠛⠱⠁⠝⠊⠲',
           original='Bit-talent u s-sens kummerċjali li kellu ma damx ma sar għani.',
           english='His talent and practical business sense made him wealthy.',
           script='Brai', flags=[], prio=PRIO_DEFAULT,
           sources=['Guy de Maupassant - Wikipedija, 22:48, 15 Mejju 2015 <https://mt.wikipedia.org/w/index.php?title=Guy_de_Maupassant&oldid=243806>', 'Guy de Maupassant - Wikipedia, 15:16, 28 May 2018 <https://en.wikipedia.org/w/index.php?title=Guy_de_Maupassant&oldid=843347873>'])


add_sample('mt', '⡊⠍⠭⠊ ⠍⠁⠇⠤⠱⠕⠇⠟⠁ ⠃⠊⠑⠭ ⠊⠎⠎⠊⠃⠓⠕⠍⠲',
           original='Imxi mal-ħolqa biex issibhom.',
           english='Click the link to find out.',
           script='Brai', flags=[], prio=PRIO_DEFAULT,
           sources=['Guy de Maupassant - Wikipedija, 22:48, 15 Mejju 2015 <https://mt.wikipedia.org/w/index.php?title=Guy_de_Maupassant&oldid=243806>'])


add_sample('vi', '⠨⠝⠔⠣⠥ ⠃⠠⠁⠝ ⠉⠔⠕ ⠧⠠⠊⠣⠉ ⠛⠰⠊ ⠉⠓⠕ ⠝⠛⠰⠁⠽ ⠍⠁⠊⠂ ⠇⠰⠁⠍ ⠓⠹⠍ ⠝⠁⠽ ⠮⠊⠲',
           original='Nếu bạn có việc gì cho ngày mai, làm hôm nay đi.',
           english='If you have something to do tomorrow, do it today.',
           script='Brai', flags=['grade1'], prio=PRIO_WITHHOLD,
           sources=['Benjamin Franklin, Wikiquote, 22:49, ngày 28 tháng 8 năm 2017 <https://vi.wikiquote.org/w/index.php?title=Benjamin_Franklin&oldid=39394>'])


add_sample('vi', '⡝⠄⢡⠭⢂⠑⠃⠋⠄⠥ ⠃⠄⢡⠭⢂⠑⠁⢂⠄⠝ ⠉⠤ ⠧⠊⠄⢡⠭⢂⠑⠉⢶⠄⠉ ⠛⠰ ⠉⠓⠕ ⠝⠛⡰⠽ ⠍⠁⠊⠂ ⠇⡰⠍ ⠓⠪⠍ ⠝⠁⠽ ⠄⢡⠭⢴⢂⢂⢂⠄⠊⠲',
           original='Nếu bạn có việc gì cho ngày mai, làm hôm nay đi.',
           english='If you have something to do tomorrow, do it today.',
           script='Brai', flags=[], prio=PRIO_DEFAULT,
           sources=['Benjamin Franklin, Wikiquote, 22:49, ngày 28 tháng 8 năm 2017 <https://vi.wikiquote.org/w/index.php?title=Benjamin_Franklin&oldid=39394>'])


add_sample('vi', '⠨⠉⠔⠁⠊ ⠃⠔⠁⠝⠓ ⠭⠑ ⠞⠠⠣ ⠝⠓⠔⠡⠞ ⠞⠠⠁⠕ ⠝⠣⠝ ⠞⠔⠊⠣⠝⠛ ⠰⠹⠝ ⠞⠕ ⠝⠓⠔⠡⠞⠲',
           original='Cái bánh xe tệ nhất tạo nên tiếng ồn to nhất.',
           english='The worst wheel of the cart makes the most noise.',
           script='Brai', flags=['grade1'], prio=PRIO_WITHHOLD,
           sources=['Benjamin Franklin, Wikiquote, 22:49, ngày 28 tháng 8 năm 2017 <https://vi.wikiquote.org/w/index.php?title=Benjamin_Franklin&oldid=39394>'])


add_sample('vi', '⡉⡔⠊ ⠃⡔⠝⠓ ⠭⠑ ⠞⠄⢡⠭⢂⠑⠉⢶⠄ ⠝⠓⠄⢡⠭⢂⠑⠁⢢⠄⠞ ⠞⠄⢡⠭⢂⠑⠁⢂⠄⠕ ⠝⢀⠝ ⠞⠊⠄⢡⠭⢂⠑⠃⠋⠄⠝⠛ ⠄⢡⠭⢂⠑⠵⢒⠄⠝ ⠞⠕ ⠝⠓⠄⢡⠭⢂⠑⠁⢢⠄⠞⠲',
           original='Cái bánh xe tệ nhất tạo nên tiếng ồn to nhất.',
           english='The worst wheel of the cart makes the most noise.',
           script='Brai', flags=[], prio=PRIO_DEFAULT,
           sources=['Benjamin Franklin, Wikiquote, 22:49, ngày 28 tháng 8 năm 2017 <https://vi.wikiquote.org/w/index.php?title=Benjamin_Franklin&oldid=39394>'])


add_sample('vi', '⠨⠝⠔⠕⠊ ⠧⠔⠪⠊ ⠞⠹⠊ ⠧⠰⠁ ⠞⠹⠊ ⠟⠥⠣⠝⠲ ⠨⠙⠠⠁⠽ ⠉⠓⠕ ⠞⠹⠊ ⠧⠰⠁ ⠞⠹⠊ ⠝⠓⠔⠪⠲ ⠨⠞⠓⠥ ⠓⠔⠥⠞ ⠞⠹⠊ ⠧⠰⠁ ⠞⠹⠊ ⠓⠠⠕⠉⠲',
           original='Nói với tôi và tôi quên. Dạy cho tôi và tôi nhớ. Thu hút tôi và tôi học.',
           english='Tell me and I forget. Teach me and I remember. Involve me and I learn.',
           script='Brai', flags=['grade1'], prio=PRIO_WITHHOLD,
           sources=['Benjamin Franklin, Wikiquote, 22:49, ngày 28 tháng 8 năm 2017 <https://vi.wikiquote.org/w/index.php?title=Benjamin_Franklin&oldid=39394>'])


add_sample('vi', '⡝⠤⠊ ⠧⠄⢡⠭⢂⠑⠵⠃⠄⠊ ⠞⠪⠊ ⠧⡰ ⠞⠪⠊ ⠟⠥⢀⠝⠲ ⡵⠄⢡⠭⢂⠑⠁⢂⠄⠽ ⠉⠓⠕ ⠞⠪⠊ ⠧⡰ ⠞⠪⠊ ⠝⠓⠄⢡⠭⢂⠑⠵⠃⠄⠲ ⡞⠓⠥ ⠓⢢⠞ ⠞⠪⠊ ⠧⡰ ⠞⠪⠊ ⠓⠄⢡⠭⢂⠑⠉⠵⠄⠉⠲',
           original='Nói với tôi và tôi quên. Dạy cho tôi và tôi nhớ. Thu hút tôi và tôi học.',
           english='Tell me and I forget. Teach me and I remember. Involve me and I learn.',
           script='Brai', flags=[], prio=PRIO_DEFAULT,
           sources=['Benjamin Franklin, Wikiquote, 22:49, ngày 28 tháng 8 năm 2017 <https://vi.wikiquote.org/w/index.php?title=Benjamin_Franklin&oldid=39394>'])


add_sample('ne', '⠖⠑⠧⠜ ⠞⠜⠇⠍⠜ ⠏⠈⠗⠝⠑ ⠍⠜⠡⠜⠏⠥⠈⠉⠈⠡⠗⠑ ⠓⠊⠍⠜⠇⠅⠕ ⠡⠜⠽⠜⠄ ⠞⠹⠜ ⠃⠑⠛⠝⠜⠎⠍⠜ ⠛⠗⠊⠝⠑ ⠫⠥⠬⠛⠜ ⠎⠧⠜⠗⠔ ⠁⠈⠞⠽⠈⠝⠞⠌ ⠍⠝⠍⠕⠓⠅ ⠡⠈⠝ ⠲',
           original='फेवा तालमा पर्ने माछापुच्छ्रे हिमालको छायाँ तथा बेगनासमा गरिने डुङगा सवारी अत्यन्तै मनमोहक छन् ।',
           english='The reflection of Mount Macchapucchre in the lakes is very beautiful.',
           script='Brai', flags=[], prio=PRIO_DEFAULT,
           sources=['नेपालका उपत्यकाहरू - विकिपिडिया ०६:४२, ७ जुन २०१८को <https://ne.wikipedia.org/w/index.php?title=%E0%A4%A8%E0%A5%87%E0%A4%AA%E0%A4%BE%E0%A4%B2%E0%A4%95%E0%A4%BE_%E0%A4%89%E0%A4%AA%E0%A4%A4%E0%A5%8D%E0%A4%AF%E0%A4%95%E0%A4%BE%E0%A4%B9%E0%A4%B0%E0%A5%82&oldid=643215>'])


add_sample('ne', '⠽⠕ ⠏⠓⠜⠫⠔ ⠟⠑⠈⠞⠗⠅⠕ ⠎⠃⠌⠘⠈⠝⠙⠜ ⠺⠳⠇⠕ ⠥⠏⠈⠞⠽⠅⠜ ⠓⠕ ⠲',
           original='यो पहाडी क्षेत्रको सबैभन्दा ठूलो उपत्यका हो ।',
           english='It is the largest valley in the mountains.',
           script='Brai', flags=[], prio=PRIO_DEFAULT,
           sources=['नेपालका उपत्यकाहरू - विकिपिडिया ०६:४२, ७ जुन २०१८को <https://ne.wikipedia.org/w/index.php?title=%E0%A4%A8%E0%A5%87%E0%A4%AA%E0%A4%BE%E0%A4%B2%E0%A4%95%E0%A4%BE_%E0%A4%89%E0%A4%AA%E0%A4%A4%E0%A5%8D%E0%A4%AF%E0%A4%95%E0%A4%BE%E0%A4%B9%E0%A4%B0%E0%A5%82&oldid=643215>'])


add_sample('ne', '⠽⠕ ⠈⠏⠽⠥⠺⠜⠝ ⠚⠊⠈⠇⠇⠜⠅⠕ ⠎⠃⠌⠘⠈⠝⠙⠜ ⠺⠳⠇⠕ ⠃⠚⠜⠗⠓⠗⠳ ⠍⠈⠮⠽⠑ ⠑⠅ ⠏⠝⠊ ⠓⠕ ⠲',
           original='यो प्युठान जिल्लाको सबैभन्दा ठूलो बजारहरू मध्ये एक पनि हो ।',
           english='It is one of the biggest markets in Pyuthan District.',
           script='Brai', flags=[], prio=PRIO_DEFAULT,
           sources=['नेपालका उपत्यकाहरू - विकिपिडिया ०६:४२, ७ जुन २०१८को <https://ne.wikipedia.org/w/index.php?title=%E0%A4%A8%E0%A5%87%E0%A4%AA%E0%A4%BE%E0%A4%B2%E0%A4%95%E0%A4%BE_%E0%A4%89%E0%A4%AA%E0%A4%A4%E0%A5%8D%E0%A4%AF%E0%A4%95%E0%A4%BE%E0%A4%B9%E0%A4%B0%E0%A5%82&oldid=643215>'])


add_sample('iu-ca', '⠕⠞⠅⠕⠞ ⠘⠏⠕⠗⠟⠘⠎⠪⠁⠟ ⠕⠞⠕⠑⠟⠕⠞⠟ ⠪⠅⠪⠅⠕⠛⠘⠞⠪⠟⠟⠕⠊⠘⠝ ⠘⠎⠘⠇⠕⠁⠪⠚⠟⠕⠊⠘⠝ ⠕⠞⠅⠕⠾⠑⠘⠍⠕⠚⠟⠲',
           original='ᑐᒃᑐ ᐱᕈᖅᓯᐊᖅ ᑐᖑᖅᑐᖅ ᑲᑲᒍᑎᖃᖅᖢᓂ ᓯᓕᐅᔭᖅᖢᓂ ᑐᒃᑑᖕᒥᔪᖅ.',
           english=None,
           script='Brai', flags=['grade1'], prio=PRIO_WITHHOLD,
           sources=['ᑐᒃᑐ - ᐅᐃᑭᐱᑎᐊ, 09:50, 28 ᑎᓯᒻᐳᕆ 2015 <https://iu.wikipedia.org/w/index.php?title=%E1%91%90%E1%92%83%E1%91%90&oldid=41369>'])


add_sample('iu-ca', '⠘⠁⠘⠚ ⠪⠁⠪⠞⠝⠘⠝⠕⠁⠪⠯ ⠘⠎⠪⠇⠗⠕⠚⠪⠁⠘⠍⠕⠁⠞ ⠘⠁⠕⠇⠟⠕⠏⠟ ⠘⠎⠪⠇⠗⠕⠚⠪⠁⠘⠍⠕⠁⠞ ⠘⠏⠞⠪⠎⠘⠞⠞⠕⠞⠟ ⠕⠁⠋⠪⠋⠲',
           original='ᐃᔨ ᐊᑕᓐᓂᐅᐹ ᓯᓚᕐᔪᐊᒥᐅᑦ ᐃᓗᖅᐳᖅ ᓯᓚᕐᔪᐊᒥᐅᑦ ᐱᑦᓴᑎᑦᑐᖅ ᐅᕝᕙ.',
           english=None,
           script='Brai', flags=['grade1'], prio=PRIO_WITHHOLD,
           sources=['ᐃᔨ - ᐅᐃᑭᐱᑎᐊ, 17:03, 7 ᒫᕐᓯ 2013 <https://iu.wikipedia.org/w/index.php?title=%E1%90%83%E1%94%A8&oldid=39206>'])


add_sample('iu-ca', '⠪⠁⠕⠁⠞⠘⠎⠪⠝⠟⠕⠞⠟ ⠕⠎⠘⠇⠪⠁⠟ ⠪⠁⠘⠝⠟⠪⠏⠪⠽⠟⠕⠾⠪⠚⠟⠕⠞⠟ ⠕⠁⠪⠇⠘⠏⠏⠪⠯ ⠪⠎⠕⠏⠍⠘⠍⠪⠫ ⠘⠞⠘⠍⠲',
           original='ᐊᐅᑦᓯᓇᖅᑐᖅ ᓱᓕᐊᖅ ᐊᓂᖅᐸᓈᖅᑑᔭᖅᑐᖅ ᐅᓚᐱᑉᐹ ᓴᐳᒻᒥᕚ ᑎᒥ.',
           english=None,
           script='Brai', flags=['grade1'], prio=PRIO_WITHHOLD,
           sources=['ᐊᐅᑦᓯᓇᖅᑐᖅ - ᐅᐃᑭᐱᑎᐊ, 18:45, 15 ᒪᐃ 2017 <https://iu.wikipedia.org/w/index.php?title=%E1%90%8A%E1%90%85%E1%91%A6%E1%93%AF%E1%93%87%E1%96%85%E1%91%90%E1%96%85&oldid=41831>'])


add_sample('haw-us', '⠠⠅⠊⠇⠕ ⠅⠈⠤⠑⠊⠁ ⠁⠅⠑⠁⠅⠁⠍⠁⠊ ⠊ ⠝⠈⠤⠁ ⠓⠈⠤⠕⠅⠈⠤⠥⠂ ⠝⠈⠤⠁ ⠓⠈⠤⠕⠅⠈⠤⠥⠓⠑⠇⠑⠂ ⠝⠈⠤⠁ ⠓⠈⠤⠕⠅⠈⠤⠥ ⠏⠥⠓⠊⠏⠁⠅⠁⠂ ⠁ ⠍⠑ ⠝⠈⠤⠁ ⠺⠊⠇⠊⠁⠥ ⠓⠈⠤⠕⠅⠈⠤⠥⠲',
           original='Kilo kēia akeakamai i nā hōkū, nā hōkūhele, nā hōkū puhipaka, a me nā wiliau hōkū.',
           english=None,
           script='Brai', flags=['grade1'], prio=PRIO_WITHHOLD,
           sources=['Kilo hōkū - Wikipedia, 12:06, 22 Kepakemapa 2014 <https://haw.wikipedia.org/w/index.php?title=Kilo_h%C5%8Dk%C5%AB&oldid=70870>'])


add_sample('haw-us', '⠠⠓⠑ ⠏⠈⠤⠁⠓⠑⠕⠝⠁ ⠅⠁ ⠓⠥⠇⠁⠓⠥⠇⠁ ⠕ ⠅⠁ ⠝⠑⠄⡳⠭⠴⠆⠃⠃⠄⠑⠝⠁ ⠕ ⠅⠑ ⠅⠊⠝⠕⠲',
           original='He pāheona ka hulahula o ka neʻena o ke kino.',
           english=None,
           script='Brai', flags=['grade1'], prio=PRIO_WITHHOLD,
           sources=['Hulahula - Wikipedia, 17:41, 11 Nowemapa 2016 <https://haw.wikipedia.org/w/index.php?title=Hulahula&oldid=72456>'])


add_sample('haw-us', '⠠⠓⠑ ⠁⠅⠑⠁⠅⠁⠍⠁⠊ ⠅⠑ ⠅⠈⠤⠁⠇⠁⠊⠅⠈⠤⠥⠇⠕⠓⠑⠁ ⠊ ⠝⠈⠤⠁ ⠍⠑⠁⠅⠊⠝⠕ ⠁ ⠍⠑ ⠅⠁ ⠄⡳⠭⠴⠆⠃⠃⠄⠕⠝⠊ ⠕ ⠝⠈⠤⠁ ⠍⠑⠁⠅⠊⠝⠕⠲',
           original='He akeakamai ke kālaikūlohea i nā meakino a me ka ʻoni o nā meakino.',
           english=None,
           script='Brai', flags=['grade1'], prio=PRIO_WITHHOLD,
           sources=['Kālaikūlohea - Wikipedia, 12:53, 22 Kepakemapa 2014 <https://haw.wikipedia.org/w/index.php?title=K%C4%81laik%C5%ABlohea&oldid=70876>'])


add_sample('se-se', '⡎⣷⠓⠞⣷⠝ ⠃⠕⠗⠗⠁⠞ ⠇⣷⠎⠁⠂ ⠙⠁⠞ ⠊⠊ ⠇⠑⠁⠞ ⠃⣷⠧⠐⢡⠭⢚⢁⢚⠙⠐⠐⢡⠭⢚⢁⢚⠙⠐⠁⠎⠄',
           original='Sáhtán borrat lása, dat ii leat bávččas.',
           english="I can eat glass and it doesn't hurt me.",
           script='Brai', flags=[], prio=PRIO_DEFAULT,
           sources=['Pango Language Sample Table', 'UTF-8 Sampler - The Kermit Project <http://kermitproject.org/utf8.html>'])

